#include <math.h>
#include "std.h"

#define EPS 1.e-8

static int nf;
static double pp;

/* chi2tab -- critical Chi2 at which the probability for Chi2 being such large is p   120798
	for n < 500, find a root of the next equation by calling rtsafe() 
		f(Chi2) = p - chi2dist(n,Chi2) = 0
	for n >= 500, use approximation from Crow et al. (1960) at p.233
	where n is the degrees of freedom.
*/

double chi2tab(n, p)
int n;
double p;
{
	void f_Chi2();
	double rl = 1.e-10, rh = 1.e3, nd, zp, dum1;


	if (n < 1) error("chi2tab: less than 1 degrees of freedom!");
	if (p < .00001 || p > .99999) error("chi2tab: p should be .00001 <= p <= .99999!");
	if (n < 500){
		nf = n;   pp = p;
		return rtsafe(f_Chi2, rl, rh, EPS);
	}
	else {
		nd = n;
		zp = -normtab(p);
		dum1 = 2./(9.*nd);
		return nd*pow(1. - dum1 + zp*sqrt(dum1), 3.);
	}
}


/* chi2dist -- probability for observed Chi2 to exceed the critical value
	n: degrees of freedom    Chi2: critical value of Chi2 (>=0)
*/

double chi2dist(n, Chi2)
int n;
double Chi2;
{
	if (n < 1) error("chi2dist: less than 1 degrees of freedom!");
	if (Chi2 < 0.) error("chi2dist: negative Chi2!");
	return gammq(n/2., Chi2/2.);
}


/* f_Chi2 -- function to determine the root for chi2tab */

void f_Chi2(x, f, df)
double x, *f, *df;
{
	*f = pp - chi2dist(nf, x);
	*df = exp( (nf/2.-1.)*log(x) - x/2. - gammln(nf/2.) - (nf/2.)*LN2 );
}


/* chi2test -- Chi-square test.  This function returns Chi2 with     090199
		probability as an argment for the observed Chi2
	BUG FIXED:
		error in the degree of freedom is fixed & new arg "g" was added   041200
	IMPORTANT NOTE:
		degree of freedom f is set according to p.85 of Crow et al. (1960) as
			f = nbin - 1 - g
		where g is the number of additional constraints determined data themselves,
		ex., g=2 if compared to normal dist. with mean & std determined from data.
*/

double chi2test(nbin, g, bin, ebin, p)
int nbin, g;
double *bin, *ebin, *p;
{
	int i;
	double chi2 = 0., dum;

	if (g < 0 || nbin - g < 1) error("Too large or negative g in chi2test!");
	for (i = 0; i < nbin; i++){
		if (ebin[i] <= 0.) error("chi2test: bad ebin!");
		dum = bin[i] - ebin[i];
		chi2 += dum*dum/ebin[i];
	}
	*p = chi2dist(nbin - 1 - g, chi2);
	return(chi2);
}

/* chi2test2 -- Chi-squatre test for two data sets using the formula 14.3.3 at p.623
	of Press et al (1992), which is for the case of different total data numbers.
	However, the degree of freedom is probably the same as the formula 14.3.2 for
	the same total data number. Hence, probably we should use g=1.
	The next memo from Press et al. is for the formula 14.3.2.
		degrees of freedom: df = nbin - g
		g -- 1 when data were collected to be equal for two dataset
		     0 when no above requirement
		     (but increase g for any additional constraints)
*/

double chi2test2(nbin, g, bin1, bin2, p)
int nbin, g;
double *bin1, *bin2, *p;
{
	int i;
	double chi2=0., sum1=0., sum2=0., dum;

	if (g<0 || nbin-g<1) error("Error of g in chi2test2!");
	for (i=0; i<nbin; i++){
		if (bin1[i]==0. || bin2[i]==0.) error("bad bin1 or bin2 in chi2test2!");
		sum1 += bin1[i];   sum2 += bin2[i];
	}
	for (i=0; i<nbin; i++){
		dum = sqrt(sum2/sum1)*bin1[i] - sqrt(sum1/sum2)*bin2[i];
		chi2 += dum*dum/(bin1[i] + bin2[i]);
	}
	*p = chi2dist(nbin-g, chi2);
	return(chi2);
}
#undef EPS
/*
printf("%f\n", rtsafe(f_Chi2, rl, rh, EPS));
printf("%f\n", nd*pow(1. - dum1 + zp*sqrt(dum1), 3.));
*/
