/* circreg -- circle fitting based on algebraic method of Taubin (1991)   072114
		rewritten in C from C++ program "CircleFitByTaubin.cpp" by,
		Prof. Nikolai Chernov, Dept. Mathematics, Univ. Alabama Birmingham.
		(http://people.cas.uab.edu/~mosya/cl/CPPcircle.html)
	Much better fitting is attained than Kasa's method, although according to
	Prof. Chernov this is to obtain initial guess for the final geometric method.
	Ver.2:
		er[i] -- sqrt(x[i]^2 + y[i]^2) - r
*/

#include <math.h>
#include "std.h"

int circreg(n, x, y, x0, y0, r, xm, ym, er, sse)
int n;
double *x, *y, *x0, *y0, *r, *xm, *ym, *er, *sse;
{
	int i, itmax=99;
	double sx=0., sy=0., mxx=0., myy=0., mxy=0., mxz=0., myz=0., mzz=0., \
		xa, ya, xi, yi, zi, mz, cov_xy, var_z, a3, a2, a1, a0, a22, a33, \
		xn, yn, dyn, xnnew, ynnew, det, xc, yc, serr=0., dum;

	for (i=0; i<n; i++){
		sx += x[i];   sy += y[i];
	}
	xa = sx/n;   ya = sy/n;
	for (i=0; i<n; i++){
		xi = x[i] - xa;   yi = y[i] - ya;
		zi = xi*xi + yi*yi;
		mxx += xi*xi;   myy += yi*yi;   mxy += xi*yi;
		mxz += xi*zi;   myz += yi*zi;   mzz += zi*zi;
	}
	mxx /= n;  myy /= n;  mxy /= n;  mxz /= n;  myz /= n;  mzz /= n;
	mz = mxx + myy;   cov_xy = mxx*myy - mxy*mxy;
	var_z = mzz - mz*mz;
	a3 = 4.*mz;   a2 = -3.*mz*mz - mzz;
	a1 = var_z*mz + 4.*cov_xy*mz - mxz*mxz - myz*myz;
	a0 = mxz*(mxz*myy - myz*mxy) + myz*(myz*mxx - mxz*mxy) - var_z*cov_xy;
	a22 = a2 + a2;   a33 = a3 + a3 + a3;
	for (xn=0.,yn=a0,i=0; i<itmax; i++){
		dyn = a1 + xn*(a22 + a33*xn);
		xnnew = xn - yn/dyn;
		if ((xnnew==xn) || (!isfinite(xnnew))) break;
		ynnew = a0 + xnnew*(a1 + xnnew*(a2 + xnnew*a3));
		if (fabs(ynnew) >= fabs(yn)) break;
		xn = xnnew;   yn = ynnew;
	}
	if (i >= itmax){
		fprintf(stderr, "Iteration exceeded itmax!");
		return -1;
	}
	det = xn*xn - xn*mz + cov_xy;
	xc = (mxz*(myy - xn) - myz*mxy)/det/2.;
	yc = (myz*(mxx - xn) - mxz*mxy)/det/2.;
	*xm = xa;   *ym = ya;
	*x0 = xc + xa;   *y0 = yc + ya;
	*r = sqrt(xc*xc + yc*yc + mz);
	for (i=0; i<n; i++){
		er[i] = sqrt((x[i]-(*x0))*(x[i]-(*x0)) + (y[i]-(*y0))*(y[i]-(*y0))) - (*r);
		serr += er[i]*er[i];
	}
	*sse = serr;
	return +1;
}
/* printf("it: %d\n", i); */

/* circregk -- regression of data points to a circle  090313
	According to Chernov & Lesort 2005, this method is first published by Kasa 1976.
	But this routine is based on private home page of an IT engineer.
	(http://imagingsolution.blog107.fc2.com/blog-entry-16.html by Akira)
	The following square is to be minimized.
		S = Sigma ((xi-x0)^2 + (yi-y0)^2 - r^2)^2
		  = Sigma (xi^2 + yi^2 - 2*x0*xi - 2*y0*yi + x0^2 + y0^2 - r^2)^2
		  = Sigma (xi^2 + yi^2 + u*xi + v*yi + w)^2
	where
		u = -2*x0
		v = -2*y0
		w = x0^2 + y0^2 - r^2
	then 
		dS/du = 0, dS/dv =0, dS/dw =0
	gives the answer. It is wonder it works because w is related to the square of x0, y0, and r!
	Residual error sse is after Paterson (2011), and xm & ym will be used for k.
	Returns:
		-1 when ludcmp() does not work, otherwise +1.
*/

#define TINY 1.0e-20

int circregk(n, x, y, x0, y0, r, xm, ym, sse)
int n;
double *x, *y, *x0, *y0, *r, *xm, *ym, *sse;
{
	int i, *indx;
	double sx=0., sy=0., sxx=0., sxy=0., syy=0., sx3=0., sxxy=0., sxyy=0., sy3=0., \
		serr=0., **a, d, *b, dum1, dum2;

	if (n <= 2) error("n<=2 in circregk");
	indx = mallocvi(4);
	a = mallocmd(4, 4);
	b = mallocvd(4);
	for (i=0; i<n; i++){
		sx += x[i];   sy += y[i];
		sxx += (dum1=x[i]*x[i]);   sxy += x[i]*y[i];   syy += (dum2=y[i]*y[i]);
		sx3 += dum1*x[i];   sxxy += dum1*y[i];   sxyy += dum2*x[i];   sy3 += dum2*y[i];
	}
	a[1][1] = sxx;   a[1][2] = sxy;   a[1][3] = sx;
	a[2][1] = sxy;   a[2][2] = syy;   a[2][3] = sy;
	a[3][1] = sx;    a[3][2] = sy;    a[3][3] = n;
	b[1] = -sx3 - sxyy;   b[2] = -sxxy - sy3;   b[3] = -sxx - syy;
	if (ludcmp(a, 3, indx, &d) == -1){
		freevi(indx);   freemd(4, a);   freevd(b);
		return -1;
	}
	lubksb(a, 3, indx, b);
	*x0 = -b[1]/2.;
	*y0 = -b[2]/2.;
	dum1 = (*x0)*(*x0) + (*y0)*(*y0) - b[3];
	if (dum1 < TINY){
		fprintf(stderr, "Too small or negative r in circregk!");
		freevi(indx);   freemd(4, a);   freevd(b);
		return -1;
	}
	*r = sqrt(dum1);
	*xm = sx/n;   *ym = sy/n;
	for (i=0; i<n; i++){
		dum1 = sqrt((x[i]-(*x0))*(x[i]-(*x0)) + (y[i]-(*y0))*(y[i]-(*y0))) - (*r);
		serr += dum1*dum1;
	}
	*sse = serr;
	freevi(indx);   freemd(4, a);   freevd(b);
	return +1;
}
#undef TINY
