#include   <math.h>
#include   "std.h"

#define EPS 1.e-10

/* fldvgp -- calculate a VGP position from paleodirection   9/5/91
		revised for singular values of sin(plat)   1996
		revised for singular sites (north and south poles)   4/18/98
*/

void fldvgp(slat, slon, inc, dec, plat, plon)
double slat, slon, inc, dec, *plat, *plon;
{
	double p, cotp, cosp, sinp, sinlt, sinplt, incr, decr, slatr, platr, plonr, dumm;

	incr = inc/RAD;   decr = dec/RAD;
	p = atan2(2.*cos(incr), sin(incr));
	if (slat >= 90.){
		*plat = 90. - RAD*p;
		*plon = 180. - dec;
	}
	else if (slat <= -90.){
		*plat = -90. + RAD*p;
		*plon = dec;
	}
	else {
		cosp = cos(p);   sinp = sin(p);
		incr = inc/RAD;   decr = dec/RAD;
		slatr = slat/RAD;
		sinlt = sin(slatr);
		sinplt = cosp*sinlt + sinp*cos(slatr)*cos(decr);
		if (sinplt >= 1.){
			*plat = 90.;   *plon = 0.;
		}
		else if (sinplt <= -1.){
			*plat = -90.;   *plon = 0.;
		}
		else {
			*plat = RAD*(platr = asin(sinplt));
			dumm = sinp*sin(decr)/cos(platr);
			if (dumm >= 1.)
				*plon = 90.;
			else if (dumm <= -1.)
				*plon = -90.;
			else 
				*plon = RAD*(plonr = asin(sinp*sin(decr)/cos(platr)));
		}
		if ((cosp-sinlt*sin(platr)) < 0.)
			*plon = 180. - *plon;
	}
	*plon += slon;
	checklon(plon, 0);
}

/* vgpfld -- vgp to filed using spherical trigonometry   0619 */

void vgpfld(slat, slon, plat, plon, inc, dec)
double slat, slon, plat, plon, *inc, *dec;
{
	double cosp, sinp, dlt, cosdlt, cosslt, sinslt, cosplt, sinplt, beta;

	cosslt = cos(slat/RAD);  sinslt = sin(slat/RAD);
	cosplt = cos(plat/RAD);  sinplt = sin(plat/RAD);
	beta = plon - slon;
	checklon(&beta, 0);
	if (fabs(plat-slat)<EPS && fabs(plon-slon)<EPS){
		*inc = 90.;  *dec = 0.;
		return;
	}
	cosp = sinslt*sinplt + cosslt*cosplt*cos(beta/RAD);
	if (cosp > 1.-EPS){
		*inc = 90.;  *dec = 0.;
		return;
	}
	if (cosp < EPS-1.){
		*inc = -90.;  *dec = 0.;
		return;
	}
	sinp = sin(acos(cosp));
	*inc = RAD*atan(2.*cosp/sinp);
	if (cosslt < EPS){
		if (slat > 0.) *dec = 180. - beta;
		else *dec = beta;
		checklon(dec, 0);
		return;
	}
	cosdlt = (sinplt - sinslt*cosp)/(cosslt*sinp);
	if (cosdlt > 1.-EPS)
		dlt = 0.;
	else if (cosdlt < EPS-1.)
		dlt = 180.;
	else
		dlt = RAD*acos((sinplt - sinslt*cosp)/(cosslt*sinp));
	if (beta>=0. && beta<=180.)
		*dec = dlt;
	else if (beta>180. && beta<360.)
		*dec = 360. - dlt;
	else
		error("error in the range of plon-slon!");
}

/* vgpfld2 -- calculate paleodirection from a VGP at a given site  09/91 
	dpm option: -1. -- set the present day total force
		    >0. -- with unit of 10^22 Am2, returns corresponding F
	revised dpm value following IGRF2015 (IGRF-12)   0519
	* RENAMED TO VGPFLD2 * after minor amendment & introducing new vgpfld  0619
*/

void vgpfld2(slat, slon, plat, plon, dpm, inc, dec, f)
double slat, slon, plat, plon, dpm, *inc, *dec, *f;
{
	double theta, g10, g11, h11, platr, plonr, slonr, cosplt, 
		costh, sinth, cossln, sinsln, x, y, z;

	if (dpm < 0.)
		dpm = -29867.9851;
	else
		dpm *= -3866.65611;
	if (fabs(plat-slat)<EPS && fabs(plon-slon)<EPS){
		*inc = 90.;  *dec = 0.;  *f = -2.*dpm;
		return;
	}
	platr = plat/RAD;  plonr = plon/RAD;
	cosplt = cos(platr);
	g10 = -sin(platr);
	g11 = -cosplt*cos(plonr);
	h11 = -cosplt*sin(plonr);
	theta = (90. - slat)/RAD;  slonr = slon/RAD;
	costh = cos(theta);  sinth = sin(theta);
	cossln = cos(slonr);  sinsln = sin(slonr);
	x = -g10*sinth + (g11*cossln + h11*sinsln)*costh;
	y = g11*sinsln - h11*cossln;
	z = -2.*g10*costh - 2.*(g11*cossln + h11*sinsln)*sinth;
	carmag(x, y, z, f, inc, dec);
	*f *= -dpm;
	if (cos(slat/RAD) < EPS){
		if (slat > 0.) *dec = 180. - (plon - slon);
		else *dec = plon - slon;
		checklon(dec, 0);
	}
}

/* fldadp -- convert a field direction to axial dipole field coordinate system 
		which was first introduced by Ken Hoffman   1/22/98
	procedure:
		1. rotate a vector 90 around z toward y, 
		2. rotate 90-incd around x toward z,
		3. rotate a vector -90 around z to restore toward x.
*/

void fldadp(slat, inc, dec, inca, deca)
double slat, inc, dec, *inca, *deca;
{
	double incd, dumm1, dumm2;

	if (slat >= 90.) incd = 90.;
	else if (slat <= -90.) incd = -90.;
	else incd = RAD*atan(2.*tan(slat/RAD));
	rotuvec(90., 90.-incd, inc, dec, &dumm1, &dumm2);
	rotuvec(-90., 0., dumm1, dumm2, inca, deca);
}

/* fldvgp2 -- dp & dm were added to fldvgp   100105 */

void fldvgp2(slat, slon, inc, dec, a95, plat, plon, dp, dm)
double slat, slon, inc, dec, a95, *plat, *plon, *dp, *dm;
{
	double p, cotp, cosp, sinp, sinlt, sinplt, incr, decr, slatr, platr, plonr, dumm;

	incr = inc/RAD;   decr = dec/RAD;
	p = atan2(2.*cos(incr), sin(incr));
	if (slat >= 90.){
		*plat = 90. - RAD*p;
		*plon = 180. - dec;
	}
	else if (slat <= -90.){
		*plat = -90. + RAD*p;
		*plon = dec;
	}
	else {
		cosp = cos(p);   sinp = sin(p);
		incr = inc/RAD;   decr = dec/RAD;
		slatr = slat/RAD;
		sinlt = sin(slatr);
		sinplt = cosp*sinlt + sinp*cos(slatr)*cos(decr);
		if (sinplt >= 1.){
			*plat = 90.;   *plon = 0.;
		}
		else if (sinplt <= -1.){
			*plat = -90.;   *plon = 0.;
		}
		else {
			*plat = RAD*(platr = asin(sinplt));
			dumm = sinp*sin(decr)/cos(platr);
			if (dumm >= 1.)
				*plon = 90.;
			else if (dumm <= -1.)
				*plon = -90.;
			else 
				*plon = RAD*(plonr = asin(sinp*sin(decr)/cos(platr)));
		}
		if ((cosp-sinlt*sin(platr)) < 0.)
			*plon = 180. - *plon;
	}
	*plon += slon;
	checklon(plon, 0);
	if (a95 >= 0.){
		*dp = .5*a95*(1. + 3.*cos(p)*cos(p));
		*dm = a95*sin(p)/cos(incr);
	}
	else {
		*dp = *dm = -1.;
	}
}
#undef EPS
