/* gausscoeff2 -- Gauss coefficients for IGRF (1900.0 <= year < 2026.0)   032520
	Ver.3: double year replaces int year so that Gauss coefficients at any time
		can be obtained. Linear interpolation is used to add secular variations
		for the time between epocks and linear extrapolation for beyond 2020.
		Data set is IGRF-13 (IAGA, Division V, Working Group V-MOD)
	Ver.2.6: IGRF-12 (Thebault et al. 2015), DGRF replaces 1995-2010   050519
	Ver.2.5: returns the nearest IGRF year or -1 when error   030919
	Ver.2.4: IGRF2015 appended, gi[][] & hi[][] are now double   040816
	Ver.2.3: IGRF2010 appended (preliminary)   030311
	Ver.2.2: IGRF2005 appended (preliminary)   071107
	Ver.2.1: IGRF2000 appended
	Ver.2: array of Gauss coeffs changed to arguments   101202
	Ver.1: Data from Barton et al. 97, JGG, 49, 121-467, 1997 (Special Vol)  011100
	NOTE:
	g[][], h[][] should be defined in the main as, double **G, etc., and memory 
	should be allocated as, G=mallocmd(n+1,n+1), etc., for maximum n (<=GNMAX).
	This function should be called at the very first of the main program
	and specific data should be stored in G[][], etc.
*/

#include <math.h>
#include "std.h"

#define NEPOCH 25

static double gi[NEPOCH+1][GNMAX+1][GNMAX+1], hi[NEPOCH+1][GNMAX+1][GNMAX+1];

int gausscoeff(year, n, g, h)
int n;
double year, **g, **h;
{
	int ie, i, j;
	double t, t0, t1, dumm;

	if (n<1 || n>GNMAX) error("gausscoeff: incorrect n!");
	if (year<1900. || year>2026.) return(-1);
	gc_igrf13();
	if ((t=year-2020.) >= 0.){
		ie = 24;
		for (i=1; i<=n; i++){
			g[i][0] = gi[ie][i][0] + gi[ie+1][i][0]*t;
			h[i][0] = 0.;
			for (j=1; j<=i; j++){
				g[i][j] = gi[ie][i][j] + gi[ie+1][i][j]*t;
				h[i][j] = hi[ie][i][j] + hi[ie+1][i][j]*t;
			}
		}
	}
	else {
		t1 = modf((year-1900.)/5., &dumm);
		ie = dumm;
		t0 = 1. - t1;
		for (i=1; i <= n; i++){
			g[i][0] = gi[ie][i][0]*t0 + gi[ie+1][i][0]*t1;
			h[i][0]=0.;
			for (j=1; j <= i; j++){
				g[i][j] = gi[ie][i][j]*t0 + gi[ie+1][i][j]*t1;
				h[i][j] = hi[ie][i][j]*t0 + hi[ie+1][i][j]*t1;
			}
		}
	}
	return (1);
}

void gc_igrf13()
{
/* IGRF1900 */

	gi[0][1][0]=-31543;
	gi[0][1][1]= -2298; hi[0][1][1]= 5922;
	gi[0][2][0]=  -677; 
	gi[0][2][1]=  2905; hi[0][2][1]=-1061; gi[0][2][2]= 924; hi[0][2][2]=1121;
	gi[0][3][0]=  1022;
	gi[0][3][1]= -1469; hi[0][3][1]= -330; gi[0][3][2]=1256; hi[0][3][2]=   3;
	gi[0][3][3]=   572; hi[0][3][3]=  523;
	gi[0][4][0]=   876;
	gi[0][4][1]=   628; hi[0][4][1]=  195; gi[0][4][2]= 660; hi[0][4][2]= -69;
	gi[0][4][3]=  -361; hi[0][4][3]= -210; gi[0][4][4]= 134; hi[0][4][4]= -75;
	gi[0][5][0]=  -184;
	gi[0][5][1]=   328; hi[0][5][1]= -210; gi[0][5][2]= 264; hi[0][5][2]=  53;
	gi[0][5][3]=     5; hi[0][5][3]=  -33; gi[0][5][4]= -86; hi[0][5][4]=-124;
	gi[0][5][5]=   -16; hi[0][5][5]=    3;
	gi[0][6][0]=    63;
	gi[0][6][1]=    61; hi[0][6][1]=   -9; gi[0][6][2]= -11; hi[0][6][2]=  83;
	gi[0][6][3]=  -217; hi[0][6][3]=    2; gi[0][6][4]= -58; hi[0][6][4]= -35;
	gi[0][6][5]=    59; hi[0][6][5]=   36; gi[0][6][6]= -90; hi[0][6][6]= -69;
	gi[0][7][0]=    70;
	gi[0][7][1]=   -55; hi[0][7][1]=  -45; gi[0][7][2]=   0; hi[0][7][2]= -13;
	gi[0][7][3]=    34; hi[0][7][3]=  -10; gi[0][7][4]= -41; hi[0][7][4]=  -1;
	gi[0][7][5]=   -21; hi[0][7][5]=   28; gi[0][7][6]=  18; hi[0][7][6]= -12;
	gi[0][7][7]=     6; hi[0][7][7]=  -22;
	gi[0][8][0]=    11;
	gi[0][8][1]=     8; hi[0][8][1]=    8; gi[0][8][2]=  -4; hi[0][8][2]= -14;
	gi[0][8][3]=    -9; hi[0][8][3]=    7; gi[0][8][4]=   1; hi[0][8][4]= -13;
	gi[0][8][5]=     2; hi[0][8][5]=    5; gi[0][8][6]=  -9; hi[0][8][6]=  16;
	gi[0][8][7]=     5; hi[0][8][7]=   -5; gi[0][8][8]=   8; hi[0][8][8]= -18;
	gi[0][9][0]=     8;
	gi[0][9][1]=    10; hi[0][9][1]=  -20; gi[0][9][2]=   1; hi[0][9][2]=  14;
	gi[0][9][3]=   -11; hi[0][9][3]=    5; gi[0][9][4]=  12; hi[0][9][4]=  -3;
	gi[0][9][5]=     1; hi[0][9][5]=   -2; gi[0][9][6]=  -2; hi[0][9][6]=   8;
	gi[0][9][7]=     2; hi[0][9][7]=   10; gi[0][9][8]=  -1; hi[0][9][8]=  -2;
	gi[0][9][9]=    -1; hi[0][9][9]=    2;
	gi[0][10][0]=   -3;
	gi[0][10][1]=   -4; hi[0][10][1]=   2; gi[0][10][2]=  2; hi[0][10][2]=  1;
	gi[0][10][3]=   -5; hi[0][10][3]=   2; gi[0][10][4]= -2; hi[0][10][4]=  6;
	gi[0][10][5]=    6; hi[0][10][5]=  -4; gi[0][10][6]=  4; hi[0][10][6]=  0;
	gi[0][10][7]=    0; hi[0][10][7]=  -2; gi[0][10][8]=  2; hi[0][10][8]=  4;
	gi[0][10][9]=    2; hi[0][10][9]=   0; gi[0][10][10]= 0; hi[0][10][10]=-6;

/* IGRF1905 */

	gi[1][1][0]=-31464;
	gi[1][1][1]= -2298; hi[1][1][1]= 5909;
	gi[1][2][0]=  -728;
	gi[1][2][1]=  2928; hi[1][2][1]=-1086; gi[1][2][2]=1041; hi[1][2][2]=1065;
	gi[1][3][0]=  1037;
	gi[1][3][1]= -1494; hi[1][3][1]= -357; gi[1][3][2]=1239; hi[1][3][2]=  34;
	gi[1][3][3]=   635; hi[1][3][3]=  480;
	gi[1][4][0]=   880;
	gi[1][4][1]=   643; hi[1][4][1]=  203; gi[1][4][2]= 653; hi[1][4][2]= -77;
	gi[1][4][3]=  -380; hi[1][4][3]= -201; gi[1][4][4]= 146; hi[1][4][4]= -65;
	gi[1][5][0]=  -192;
	gi[1][5][1]=   328; hi[1][5][1]= -193; gi[1][5][2]= 259; hi[1][5][2]=  56;
	gi[1][5][3]=    -1; hi[1][5][3]=  -32; gi[1][5][4]= -93; hi[1][5][4]=-125;
	gi[1][5][5]=   -26; hi[1][5][5]=   11;
	gi[1][6][0]=    62;
	gi[1][6][1]=    60; hi[1][6][1]=   -7; gi[1][6][2]= -11; hi[1][6][2]=  86;
	gi[1][6][3]=  -221; hi[1][6][3]=    4; gi[1][6][4]= -57; hi[1][6][4]= -32;
	gi[1][6][5]=    57; hi[1][6][5]=   32; gi[1][6][6]= -92; hi[1][6][6]= -67;
	gi[1][7][0]=    70;
	gi[1][7][1]=   -54; hi[1][7][1]=  -46; gi[1][7][2]=   0; hi[1][7][2]= -14;
	gi[1][7][3]=    33; hi[1][7][3]=  -11; gi[1][7][4]= -41; hi[1][7][4]=   0;
	gi[1][7][5]=   -20; hi[1][7][5]=   28; gi[1][7][6]=  18; hi[1][7][6]= -12;
	gi[1][7][7]=     6; hi[1][7][7]=  -22;
	gi[1][8][0]=    11;
	gi[1][8][1]=     8; hi[1][8][1]=    8; gi[1][8][2]=  -4; hi[1][8][2]= -15;
	gi[1][8][3]=    -9; hi[1][8][3]=    7; gi[1][8][4]=   1; hi[1][8][4]= -13;
	gi[1][8][5]=     2; hi[1][8][5]=    5; gi[1][8][6]=  -8; hi[1][8][6]=  16;
	gi[1][8][7]=     5; hi[1][8][7]=   -5; gi[1][8][8]=   8; hi[1][8][8]= -18;
	gi[1][9][0]=     8;
	gi[1][9][1]=    10; hi[1][9][1]=  -20; gi[1][9][2]=   1; hi[1][9][2]=  14;
	gi[1][9][3]=   -11; hi[1][9][3]=    5; gi[1][9][4]=  12; hi[1][9][4]=  -3;
	gi[1][9][5]=     1; hi[1][9][5]=   -2; gi[1][9][6]=  -2; hi[1][9][6]=   8;
	gi[1][9][7]=     2; hi[1][9][7]=   10; gi[1][9][8]=   0; hi[1][9][8]=  -2;
	gi[1][9][9]=    -1; hi[1][9][9]=    2;
	gi[1][10][0]=   -3;
	gi[1][10][1]=   -4; hi[1][10][1]=   2; gi[1][10][2]=  2; hi[1][10][2]=  1;
	gi[1][10][3]=   -5; hi[1][10][3]=   2; gi[1][10][4]= -2; hi[1][10][4]=  6;
	gi[1][10][5]=    6; hi[1][10][5]=  -4; gi[1][10][6]=  4; hi[1][10][6]=  0;
	gi[1][10][7]=    0; hi[1][10][7]=  -2; gi[1][10][8]=  2; hi[1][10][8]=  4;
	gi[1][10][9]=    2; hi[1][10][9]=   0; gi[1][10][10]= 0; hi[1][10][10]=-6;

/* IGRF1910 */

	gi[2][1][0]=-31354;
	gi[2][1][1]= -2297; hi[2][1][1]=5898;
	gi[2][2][0]=  -769;
	gi[2][2][1]=  2948; hi[2][2][1]=-1128; gi[2][2][2]=1176; hi[2][2][2]=1000;
	gi[2][3][0]=  1058;
	gi[2][3][1]= -1524; hi[2][3][1]= -389; gi[2][3][2]=1223; hi[2][3][2]=  62;
	gi[2][3][3]=   705; hi[2][3][3]=  425;
	gi[2][4][0]=   884;
	gi[2][4][1]=   660; hi[2][4][1]=  211; gi[2][4][2]= 644; hi[2][4][2]= -90;
	gi[2][4][3]=  -400; hi[2][4][3]= -189; gi[2][4][4]= 160; hi[2][4][4]= -55;
	gi[2][5][0]=  -201;
	gi[2][5][1]=   327; hi[2][5][1]= -172; gi[2][5][2]= 253; hi[2][5][2]=  57;
	gi[2][5][3]=    -9; hi[2][5][3]=  -33; gi[2][5][4]=-102; hi[2][5][4]=-126;
	gi[2][5][5]=   -38; hi[2][5][5]=   21;
	gi[2][6][0]=    62;
	gi[2][6][1]=    58; hi[2][6][1]=   -5; gi[2][6][2]= -11; hi[2][6][2]=  89;
	gi[2][6][3]=  -224; hi[2][6][3]=    5; gi[2][6][4]= -54; hi[2][6][4]= -29;
	gi[2][6][5]=    54; hi[2][6][5]=   28; gi[2][6][6]= -95; hi[2][6][6]= -65;
	gi[2][7][0]=    71;
	gi[2][7][1]=   -54; hi[2][7][1]=  -47; gi[2][7][2]=   1; hi[2][7][2]= -14;
	gi[2][7][3]=    32; hi[2][7][3]=  -12; gi[2][7][4]= -40; hi[2][7][4]=   1;
	gi[2][7][5]=   -19; hi[2][7][5]=   28; gi[2][7][6]=  18; hi[2][7][6]= -13;
	gi[2][7][7]=     6; hi[2][7][7]=  -22;
	gi[2][8][0]=    11;
	gi[2][8][1]=     8; hi[2][8][1]=    8; gi[2][8][2]=  -4; hi[2][8][2]= -15;
	gi[2][8][3]=    -9; hi[2][8][3]=    6; gi[2][8][4]=   1; hi[2][8][4]= -13;
	gi[2][8][5]=     2; hi[2][8][5]=    5; gi[2][8][6]=  -8; hi[2][8][6]=  16;
	gi[2][8][7]=     5; hi[2][8][7]=   -5; gi[2][8][8]=   8; hi[2][8][8]= -18;
	gi[2][9][0]=     8;
	gi[2][9][1]=    10; hi[2][9][1]=  -20; gi[2][9][2]=   1; hi[2][9][2]=  14;
	gi[2][9][3]=   -11; hi[2][9][3]=    5; gi[2][9][4]=  12; hi[2][9][4]=  -3;
	gi[2][9][5]=     1; hi[2][9][5]=   -2; gi[2][9][6]=  -2; hi[2][9][6]=   8;
	gi[2][9][7]=     2; hi[2][9][7]=   10; gi[2][9][8]=   0; hi[2][9][8]=  -2;
	gi[2][9][9]=    -1; hi[2][9][9]=    2;
	gi[2][10][0]=   -3;
	gi[2][10][1]=   -4; hi[2][10][1]=   2; gi[2][10][2]=  2; hi[2][10][2]=  1;
	gi[2][10][3]=   -5; hi[2][10][3]=   2; gi[2][10][4]= -2; hi[2][10][4]=  6;
	gi[2][10][5]=    6; hi[2][10][5]=  -4; gi[2][10][6]=  4; hi[2][10][6]=  0;
	gi[2][10][7]=    0; hi[2][10][7]=  -2; gi[2][10][8]=  2; hi[2][10][8]=  4;
	gi[2][10][9]=    2; hi[2][10][9]=   0; gi[2][10][10]= 0; hi[2][10][10]=-6;

/* IGRF1915 */

	gi[3][1][0]=-31212;
	gi[3][1][1]= -2306; hi[3][1][1]= 5875;
	gi[3][2][0]=  -802;
	gi[3][2][1]=  2956; hi[3][2][1]=-1191; gi[3][2][2]=1309; hi[3][2][2]= 917;
	gi[3][3][0]=  1084;
	gi[3][3][1]= -1559; hi[3][3][1]= -421; gi[3][3][2]=1212; hi[3][3][2]=  84;
	gi[3][3][3]=   778; hi[3][3][3]=  360;
	gi[3][4][0]=   887;
	gi[3][4][1]=   678; hi[3][4][1]=  218; gi[3][4][2]= 631; hi[3][4][2]=-109;
	gi[3][4][3]=  -416; hi[3][4][3]= -173; gi[3][4][4]= 178; hi[3][4][4]= -51;
	gi[3][5][0]=  -211;
	gi[3][5][1]=   327; hi[3][5][1]= -148; gi[3][5][2]= 245; hi[3][5][2]=  58;
	gi[3][5][3]=   -16; hi[3][5][3]=  -34; gi[3][5][4]=-111; hi[3][5][4]=-126;
	gi[3][5][5]=   -51; hi[3][5][5]=   32;
	gi[3][6][0]=    61;
	gi[3][6][1]=    57; hi[3][6][1]=   -2; gi[3][6][2]= -10; hi[3][6][2]=  93;
	gi[3][6][3]=  -228; hi[3][6][3]=    8; gi[3][6][4]= -51; hi[3][6][4]= -26;
	gi[3][6][5]=    49; hi[3][6][5]=   23; gi[3][6][6]= -98; hi[3][6][6]= -62;
	gi[3][7][0]=    72;
	gi[3][7][1]=   -54; hi[3][7][1]=  -48; gi[3][7][2]=   2; hi[3][7][2]= -14;
	gi[3][7][3]=    31; hi[3][7][3]=  -12; gi[3][7][4]= -38; hi[3][7][4]=   2;
	gi[3][7][5]=   -18; hi[3][7][5]=   28; gi[3][7][6]=  19; hi[3][7][6]= -15;
	gi[3][7][7]=     6; hi[3][7][7]=  -22;
	gi[3][8][0]=    11;
	gi[3][8][1]=     8; hi[3][8][1]=    8; gi[3][8][2]=  -4; hi[3][8][2]= -15;
	gi[3][8][3]=    -9; hi[3][8][3]=    6; gi[3][8][4]=   2; hi[3][8][4]= -13;
	gi[3][8][5]=     3; hi[3][8][5]=    5; gi[3][8][6]=  -8; hi[3][8][6]=  16;
	gi[3][8][7]=     6; hi[3][8][7]=   -5; gi[3][8][8]=   8; hi[3][8][8]= -18;
	gi[3][9][0]=     8;
	gi[3][9][1]=    10; hi[3][9][1]=  -20; gi[3][9][2]=   1; hi[3][9][2]=  14;
	gi[3][9][3]=   -11; hi[3][9][3]=    5; gi[3][9][4]=  12; hi[3][9][4]=  -3;
	gi[3][9][5]=     1; hi[3][9][5]=   -2; gi[3][9][6]=  -2; hi[3][9][6]=   8;
	gi[3][9][7]=     2; hi[3][9][7]=   10; gi[3][9][8]=   0; hi[3][9][8]=  -2;
	gi[3][9][9]=    -1; hi[3][9][9]=    2;
	gi[3][10][0]=   -3;
	gi[3][10][1]=   -4; hi[3][10][1]=   2; gi[3][10][2]=  2; hi[3][10][2]=  1;
	gi[3][10][3]=   -5; hi[3][10][3]=   2; gi[3][10][4]= -2; hi[3][10][4]=  6;
	gi[3][10][5]=    6; hi[3][10][5]=  -4; gi[3][10][6]=  4; hi[3][10][6]=  0;
	gi[3][10][7]=    0; hi[3][10][7]=  -2; gi[3][10][8]=  1; hi[3][10][8]=  4;
	gi[3][10][9]=    2; hi[3][10][9]=   0; gi[3][10][10]= 0; hi[3][10][10]=-6;

/* IGRF1920 */

	gi[4][1][0]=-31060;
	gi[4][1][1]= -2317; hi[4][1][1]= 5845;
	gi[4][2][0]=  -839;
	gi[4][2][1]=  2959; hi[4][2][1]=-1259; gi[4][2][2]=1407; hi[4][2][2]= 823;
	gi[4][3][0]=  1111;
	gi[4][3][1]= -1600; hi[4][3][1]= -445; gi[4][3][2]=1205; hi[4][3][2]= 103;
	gi[4][3][3]=   839; hi[4][3][3]=  293;
	gi[4][4][0]=   889;
	gi[4][4][1]=   695; hi[4][4][1]=  220; gi[4][4][2]= 616; hi[4][4][2]=-134;
	gi[4][4][3]=  -424; hi[4][4][3]= -153; gi[4][4][4]= 199; hi[4][4][4]= -57;
	gi[4][5][0]=  -221;
	gi[4][5][1]=   326; hi[4][5][1]= -122; gi[4][5][2]= 236; hi[4][5][2]=  58;
	gi[4][5][3]=   -23; hi[4][5][3]=  -38; gi[4][5][4]=-119; hi[4][5][4]=-125;
	gi[4][5][5]=   -62; hi[4][5][5]=   43;
	gi[4][6][0]=    61;
	gi[4][6][1]=    55; hi[4][6][1]=    0; gi[4][6][2]= -10; hi[4][6][2]=  96;
	gi[4][6][3]=  -233; hi[4][6][3]=   11; gi[4][6][4]= -46; hi[4][6][4]= -22;
	gi[4][6][5]=    44; hi[4][6][5]=   18; gi[4][6][6]=-101; hi[4][6][6]= -57;
	gi[4][7][0]=    73;
	gi[4][7][1]=   -54; hi[4][7][1]=  -49; gi[4][7][2]=   2; hi[4][7][2]= -14;
	gi[4][7][3]=    29; hi[4][7][3]=  -13; gi[4][7][4]= -37; hi[4][7][4]=   4;
	gi[4][7][5]=   -16; hi[4][7][5]=   28; gi[4][7][6]=  19; hi[4][7][6]= -16;
	gi[4][7][7]=     6; hi[4][7][7]=  -22;
	gi[4][8][0]=    11;
	gi[4][8][1]=     7; hi[4][8][1]=    8; gi[4][8][2]=  -3; hi[4][8][2]= -15;
	gi[4][8][3]=    -9; hi[4][8][3]=    6; gi[4][8][4]=   2; hi[4][8][4]= -14;
	gi[4][8][5]=     4; hi[4][8][5]=    5; gi[4][8][6]=  -7; hi[4][8][6]=  17;
	gi[4][8][7]=     6; hi[4][8][7]=   -5; gi[4][8][8]=   8; hi[4][8][8]= -19;
	gi[4][9][0]=     8;
	gi[4][9][1]=    10; hi[4][9][1]=  -20; gi[4][9][2]=   1; hi[4][9][2]=  14;
	gi[4][9][3]=   -11; hi[4][9][3]=    5; gi[4][9][4]=  12; hi[4][9][4]=  -3;
	gi[4][9][5]=     1; hi[4][9][5]=   -2; gi[4][9][6]=  -2; hi[4][9][6]=   9;
	gi[4][9][7]=     2; hi[4][9][7]=   10; gi[4][9][8]=   0; hi[4][9][8]=  -2;
	gi[4][9][9]=    -1; hi[4][9][9]=    2;
	gi[4][10][0]=   -3;
	gi[4][10][1]=   -4; hi[4][10][1]=   2; gi[4][10][2]=  2; hi[4][10][2]=  1;
	gi[4][10][3]=   -5; hi[4][10][3]=   2; gi[4][10][4]= -2; hi[4][10][4]=  6;
	gi[4][10][5]=    6; hi[4][10][5]=  -4; gi[4][10][6]=  4; hi[4][10][6]=  0;
	gi[4][10][7]=    0; hi[4][10][7]=  -2; gi[4][10][8]=  1; hi[4][10][8]=  4;
	gi[4][10][9]=    3; hi[4][10][9]=   0; gi[4][10][10]= 0; hi[4][10][10]=-6;

/* IGRF1925 */

	gi[5][1][0]=-30926;
	gi[5][1][1]= -2318; hi[5][1][1]= 5817;
	gi[5][2][0]=  -893;
	gi[5][2][1]=  2969; hi[5][2][1]=-1334; gi[5][2][2]=1471; hi[5][2][2]= 728;
	gi[5][3][0]=  1140;
	gi[5][3][1]= -1645; hi[5][3][1]= -462; gi[5][3][2]=1202; hi[5][3][2]= 119;
	gi[5][3][3]=   881; hi[5][3][3]=  229;
	gi[5][4][0]=   891;
	gi[5][4][1]=   711; hi[5][4][1]=  216; gi[5][4][2]= 601; hi[5][4][2]=-163;
	gi[5][4][3]=  -426; hi[5][4][3]= -130; gi[5][4][4]= 217; hi[5][4][4]= -70;
	gi[5][5][0]=  -230;
	gi[5][5][1]=   326; hi[5][5][1]=  -96; gi[5][5][2]= 226; hi[5][5][2]=  58;
	gi[5][5][3]=   -28; hi[5][5][3]=  -44; gi[5][5][4]=-125; hi[5][5][4]=-122;
	gi[5][5][5]=   -69; hi[5][5][5]=   51;
	gi[5][6][0]=    61;
	gi[5][6][1]=    54; hi[5][6][1]=    3; gi[5][6][2]=  -9; hi[5][6][2]=  99;
	gi[5][6][3]=  -238; hi[5][6][3]=   14; gi[5][6][4]= -40; hi[5][6][4]= -18;
	gi[5][6][5]=    39; hi[5][6][5]=   13; gi[5][6][6]=-103; hi[5][6][6]= -52;
	gi[5][7][0]=    73;
	gi[5][7][1]=   -54; hi[5][7][1]=  -50; gi[5][7][2]=   3; hi[5][7][2]= -14;
	gi[5][7][3]=    27; hi[5][7][3]=  -14; gi[5][7][4]= -35; hi[5][7][4]=   5;
	gi[5][7][5]=   -14; hi[5][7][5]=   29; gi[5][7][6]=  19; hi[5][7][6]= -17;
	gi[5][7][7]=     6; hi[5][7][7]=  -21;
	gi[5][8][0]=    11;
	gi[5][8][1]=     7; hi[5][8][1]=    8; gi[5][8][2]=  -3; hi[5][8][2]= -15;
	gi[5][8][3]=    -9; hi[5][8][3]=    6; gi[5][8][4]=   2; hi[5][8][4]= -14;
	gi[5][8][5]=     4; hi[5][8][5]=    5; gi[5][8][6]=  -7; hi[5][8][6]=  17;
	gi[5][8][7]=     7; hi[5][8][7]=   -5; gi[5][8][8]=   8; hi[5][8][8]= -19;
	gi[5][9][0]=     8;
	gi[5][9][1]=    10; hi[5][9][1]=  -20; gi[5][9][2]=   1; hi[5][9][2]=  14;
	gi[5][9][3]=   -11; hi[5][9][3]=    5; gi[5][9][4]=  12; hi[5][9][4]=  -3;
	gi[5][9][5]=     1; hi[5][9][5]=   -2; gi[5][9][6]=  -2; hi[5][9][6]=   9;
	gi[5][9][7]=     2; hi[5][9][7]=   10; gi[5][9][8]=   0; hi[5][9][8]=  -2;
	gi[5][9][9]=    -1; hi[5][9][9]=    2;
	gi[5][10][0]=   -3;
	gi[5][10][1]=   -4; hi[5][10][1]=   2; gi[5][10][2]=  2; hi[5][10][2]=  1;
	gi[5][10][3]=   -5; hi[5][10][3]=   2; gi[5][10][4]= -2; hi[5][10][4]=  6;
	gi[5][10][5]=    6; hi[5][10][5]=  -4; gi[5][10][6]=  4; hi[5][10][6]=  0;
	gi[5][10][7]=    0; hi[5][10][7]=  -2; gi[5][10][8]=  1; hi[5][10][8]=  4;
	gi[5][10][9]=    3; hi[5][10][9]=   0; gi[5][10][10]= 0; hi[5][10][10]=-6;

/* IGRF1930 */

	gi[6][1][0]=-30805;
	gi[6][1][1]= -2316; hi[6][1][1]= 5808;
	gi[6][2][0]=  -951;
	gi[6][2][1]=  2980; hi[6][2][1]=-1424; gi[6][2][2]=1517; hi[6][2][2]= 644;
	gi[6][3][0]=  1172;
	gi[6][3][1]= -1692; hi[6][3][1]= -480; gi[6][3][2]=1205; hi[6][3][2]= 133;
	gi[6][3][3]=   907; hi[6][3][3]=  166;
	gi[6][4][0]=   896;
	gi[6][4][1]=   727; hi[6][4][1]=  205; gi[6][4][2]= 584; hi[6][4][2]=-195;
	gi[6][4][3]=  -422; hi[6][4][3]= -109; gi[6][4][4]= 234; hi[6][4][4]= -90;
	gi[6][5][0]=  -237;
	gi[6][5][1]=   327; hi[6][5][1]=  -72; gi[6][5][2]= 218; hi[6][5][2]=  60;
	gi[6][5][3]=   -32; hi[6][5][3]=  -53; gi[6][5][4]=-131; hi[6][5][4]=-118;
	gi[6][5][5]=   -74; hi[6][5][5]=   58;
	gi[6][6][0]=    60;
	gi[6][6][1]=    53; hi[6][6][1]=    4; gi[6][6][2]=  -9; hi[6][6][2]= 102;
	gi[6][6][3]=  -242; hi[6][6][3]=   19; gi[6][6][4]= -32; hi[6][6][4]= -16;
	gi[6][6][5]=    32; hi[6][6][5]=    8; gi[6][6][6]=-104; hi[6][6][6]= -46;
	gi[6][7][0]=    74;
	gi[6][7][1]=   -54; hi[6][7][1]=  -51; gi[6][7][2]=   4; hi[6][7][2]= -15;
	gi[6][7][3]=    25; hi[6][7][3]=  -14; gi[6][7][4]= -34; hi[6][7][4]=   6;
	gi[6][7][5]=   -12; hi[6][7][5]=   29; gi[6][7][6]=  18; hi[6][7][6]= -18;
	gi[6][7][7]=     6; hi[6][7][7]=  -20;
	gi[6][8][0]=    11;
	gi[6][8][1]=     7; hi[6][8][1]=    8; gi[6][8][2]=  -3; hi[6][8][2]= -15;
	gi[6][8][3]=    -9; hi[6][8][3]=    5; gi[6][8][4]=   2; hi[6][8][4]= -14;
	gi[6][8][5]=     5; hi[6][8][5]=    5; gi[6][8][6]=  -6; hi[6][8][6]=  18;
	gi[6][8][7]=     8; hi[6][8][7]=   -5; gi[6][8][8]=   8; hi[6][8][8]= -19;
	gi[6][9][0]=     8;
	gi[6][9][1]=    10; hi[6][9][1]=  -20; gi[6][9][2]=   1; hi[6][9][2]=  14;
	gi[6][9][3]=   -12; hi[6][9][3]=    5; gi[6][9][4]=  12; hi[6][9][4]=  -3;
	gi[6][9][5]=     1; hi[6][9][5]=   -2; gi[6][9][6]=  -2; hi[6][9][6]=   9;
	gi[6][9][7]=     3; hi[6][9][7]=   10; gi[6][9][8]=   0; hi[6][9][8]=  -2;
	gi[6][9][9]=    -2; hi[6][9][9]=    2;
	gi[6][10][0]=   -3;
	gi[6][10][1]=   -4; hi[6][10][1]=   2; gi[6][10][2]=  2; hi[6][10][2]=  1;
	gi[6][10][3]=   -5; hi[6][10][3]=   2; gi[6][10][4]= -2; hi[6][10][4]=  6;
	gi[6][10][5]=    6; hi[6][10][5]=  -4; gi[6][10][6]=  4; hi[6][10][6]=  0;
	gi[6][10][7]=    0; hi[6][10][7]=  -2; gi[6][10][8]=  1; hi[6][10][8]=  4;
	gi[6][10][9]=    3; hi[6][10][9]=   0; gi[6][10][10]= 0; hi[6][10][10]=-6;

/* IGRF1935 */

	gi[7][1][0]=-30715;
	gi[7][1][1]= -2306; hi[7][1][1]= 5812;
	gi[7][2][0]= -1018;
	gi[7][2][1]=  2984; hi[7][2][1]=-1520; gi[7][2][2]=1550; hi[7][2][2]= 586;
	gi[7][3][0]=  1206;
	gi[7][3][1]= -1740; hi[7][3][1]= -494; gi[7][3][2]=1215; hi[7][3][2]= 146;
	gi[7][3][3]=   918; hi[7][3][3]=  101;
	gi[7][4][0]=   903;
	gi[7][4][1]=   744; hi[7][4][1]=  188; gi[7][4][2]= 565; hi[7][4][2]=-226;
	gi[7][4][3]=  -415; hi[7][4][3]=  -90; gi[7][4][4]= 249; hi[7][4][4]=-114;
	gi[7][5][0]=  -241;
	gi[7][5][1]=   329; hi[7][5][1]=  -51; gi[7][5][2]= 211; hi[7][5][2]=  64;
	gi[7][5][3]=   -33; hi[7][5][3]=  -64; gi[7][5][4]=-136; hi[7][5][4]=-115;
	gi[7][5][5]=   -76; hi[7][5][5]=   64;
	gi[7][6][0]=    59;
	gi[7][6][1]=    53; hi[7][6][1]=    4; gi[7][6][2]=  -8; hi[7][6][2]= 104;
	gi[7][6][3]=  -246; hi[7][6][3]=   25; gi[7][6][4]= -25; hi[7][6][4]= -15;
	gi[7][6][5]=    25; hi[7][6][5]=    4; gi[7][6][6]=-106; hi[7][6][6]= -40;
	gi[7][7][0]=    74;
	gi[7][7][1]=   -53; hi[7][7][1]=  -52; gi[7][7][2]=   4; hi[7][7][2]= -17;
	gi[7][7][3]=    23; hi[7][7][3]=  -14; gi[7][7][4]= -33; hi[7][7][4]=   7;
	gi[7][7][5]=   -11; hi[7][7][5]=   29; gi[7][7][6]=  18; hi[7][7][6]= -19;
	gi[7][7][7]=     6; hi[7][7][7]=  -19;
	gi[7][8][0]=    11;
	gi[7][8][1]=     7; hi[7][8][1]=    8; gi[7][8][2]=  -3; hi[7][8][2]= -15;
	gi[7][8][3]=    -9; hi[7][8][3]=    5; gi[7][8][4]=   1; hi[7][8][4]= -15;
	gi[7][8][5]=     6; hi[7][8][5]=    5; gi[7][8][6]=  -6; hi[7][8][6]=  18;
	gi[7][8][7]=     8; hi[7][8][7]=   -5; gi[7][8][8]=   7; hi[7][8][8]= -19;
	gi[7][9][0]=     8;
	gi[7][9][1]=    10; hi[7][9][1]=  -20; gi[7][9][2]=   1; hi[7][9][2]=  15;
	gi[7][9][3]=   -12; hi[7][9][3]=    5; gi[7][9][4]=  11; hi[7][9][4]=  -3;
	gi[7][9][5]=     1; hi[7][9][5]=   -3; gi[7][9][6]=  -2; hi[7][9][6]=   9;
	gi[7][9][7]=     3; hi[7][9][7]=   11; gi[7][9][8]=   0; hi[7][9][8]=  -2;
	gi[7][9][9]=    -2; hi[7][9][9]=    2;
	gi[7][10][0]=   -3;
	gi[7][10][1]=   -4; hi[7][10][1]=   2; gi[7][10][2]=  2; hi[7][10][2]=  1;
	gi[7][10][3]=   -5; hi[7][10][3]=   2; gi[7][10][4]= -2; hi[7][10][4]=  6;
	gi[7][10][5]=    6; hi[7][10][5]=  -4; gi[7][10][6]=  4; hi[7][10][6]=  0;
	gi[7][10][7]=    0; hi[7][10][7]=  -1; gi[7][10][8]=  2; hi[7][10][8]=  4;
	gi[7][10][9]=    3; hi[7][10][9]=   0; gi[7][10][10]= 0; hi[7][10][10]=-6;

/* IGRF1940 */

	gi[8][1][0]=-30654;
	gi[8][1][1]= -2292; hi[8][1][1]= 5821;
	gi[8][2][0]= -1106;
	gi[8][2][1]=  2981; hi[8][2][1]=-1614; gi[8][2][2]=1566; hi[8][2][2]= 528;
	gi[8][3][0]=  1240;
	gi[8][3][1]= -1790; hi[8][3][1]= -499; gi[8][3][2]=1232; hi[8][3][2]= 163;
	gi[8][3][3]=   916; hi[8][3][3]=   43;
	gi[8][4][0]=   914;
	gi[8][4][1]=   762; hi[8][4][1]=  169; gi[8][4][2]= 550; hi[8][4][2]=-252;
	gi[8][4][3]=  -405; hi[8][4][3]=  -72; gi[8][4][4]= 265; hi[8][4][4]=-141;
	gi[8][5][0]=  -241;
	gi[8][5][1]=   334; hi[8][5][1]=  -33; gi[8][5][2]= 208; hi[8][5][2]=  71;
	gi[8][5][3]=   -33; hi[8][5][3]=  -75; gi[8][5][4]=-141; hi[8][5][4]=-113;
	gi[8][5][5]=   -76; hi[8][5][5]=   69;
	gi[8][6][0]=    57;
	gi[8][6][1]=    54; hi[8][6][1]=    4; gi[8][6][2]=  -7; hi[8][6][2]= 105;
	gi[8][6][3]=  -249; hi[8][6][3]=   33; gi[8][6][4]= -18; hi[8][6][4]= -15;
	gi[8][6][5]=    18; hi[8][6][5]=    0; gi[8][6][6]=-107; hi[8][6][6]= -33;
	gi[8][7][0]=    74;
	gi[8][7][1]=   -53; hi[8][7][1]=  -52; gi[8][7][2]=   4; hi[8][7][2]= -18;
	gi[8][7][3]=    20; hi[8][7][3]=  -14; gi[8][7][4]= -31; hi[8][7][4]=   7;
	gi[8][7][5]=    -9; hi[8][7][5]=   29; gi[8][7][6]=  17; hi[8][7][6]= -20;
	gi[8][7][7]=     5; hi[8][7][7]=  -19;
	gi[8][8][0]=    11;
	gi[8][8][1]=     7; hi[8][8][1]=    8; gi[8][8][2]=  -3; hi[8][8][2]= -14;
	gi[8][8][3]=   -10; hi[8][8][3]=    5; gi[8][8][4]=   1; hi[8][8][4]= -15;
	gi[8][8][5]=     6; hi[8][8][5]=    5; gi[8][8][6]=  -5; hi[8][8][6]=  19;
	gi[8][8][7]=     9; hi[8][8][7]=   -5; gi[8][8][8]=   7; hi[8][8][8]= -19;
	gi[8][9][0]=     8;
	gi[8][9][1]=    10; hi[8][9][1]=  -21; gi[8][9][2]=   1; hi[8][9][2]=  15;
	gi[8][9][3]=   -12; hi[8][9][3]=    5; gi[8][9][4]=  11; hi[8][9][4]=  -3;
	gi[8][9][5]=     1; hi[8][9][5]=   -3; gi[8][9][6]=  -2; hi[8][9][6]=   9;
	gi[8][9][7]=     3; hi[8][9][7]=   11; gi[8][9][8]=   1; hi[8][9][8]=  -2;
	gi[8][9][9]=    -2; hi[8][9][9]=    2;
	gi[8][10][0]=   -3;
	gi[8][10][1]=   -4; hi[8][10][1]=   2; gi[8][10][2]=  2; hi[8][10][2]=  1;
	gi[8][10][3]=   -5; hi[8][10][3]=   2; gi[8][10][4]= -2; hi[8][10][4]=  6;
	gi[8][10][5]=    6; hi[8][10][5]=  -4; gi[8][10][6]=  4; hi[8][10][6]=  0;
	gi[8][10][7]=    0; hi[8][10][7]=  -1; gi[8][10][8]=  2; hi[8][10][8]=  4;
	gi[8][10][9]=    3; hi[8][10][9]=   0; gi[8][10][10]= 0; hi[8][10][10]=-6;

/* DGRF1945 */

	gi[9][1][0]=-30594;
	gi[9][1][1]= -2285; hi[9][1][1]= 5810;
	gi[9][2][0]= -1244;
	gi[9][2][1]=  2990; hi[9][2][1]=-1702; gi[9][2][2]=1578; hi[9][2][2]= 477;
	gi[9][3][0]=  1282;
	gi[9][3][1]= -1834; hi[9][3][1]= -499; gi[9][3][2]=1255; hi[9][3][2]= 186;
	gi[9][3][3]=   913; hi[9][3][3]=  -11;
	gi[9][4][0]=   944;
	gi[9][4][1]=   776; hi[9][4][1]=  144; gi[9][4][2]= 544; hi[9][4][2]=-276;
	gi[9][4][3]=  -421; hi[9][4][3]=  -55; gi[9][4][4]= 304; hi[9][4][4]=-178;
	gi[9][5][0]=  -253;
	gi[9][5][1]=   346; hi[9][5][1]=  -12; gi[9][5][2]= 194; hi[9][5][2]=  95;
	gi[9][5][3]=   -20; hi[9][5][3]=  -67; gi[9][5][4]=-142; hi[9][5][4]=-119;
	gi[9][5][5]=   -82; hi[9][5][5]=   82;
	gi[9][6][0]=    59;
	gi[9][6][1]=    57; hi[9][6][1]=    6; gi[9][6][2]=   6; hi[9][6][2]= 100;
	gi[9][6][3]=  -246; hi[9][6][3]=   16; gi[9][6][4]= -25; hi[9][6][4]=  -9;
	gi[9][6][5]=    21; hi[9][6][5]=  -16; gi[9][6][6]=-104; hi[9][6][6]= -39;
	gi[9][7][0]=    70;
	gi[9][7][1]=   -40; hi[9][7][1]=  -45; gi[9][7][2]=   0; hi[9][7][2]= -18;
	gi[9][7][3]=     0; hi[9][7][3]=    2; gi[9][7][4]= -29; hi[9][7][4]=   6;
	gi[9][7][5]=   -10; hi[9][7][5]=   28; gi[9][7][6]=  15; hi[9][7][6]= -17;
	gi[9][7][7]=    29; hi[9][7][7]=  -22;
	gi[9][8][0]=    13;
	gi[9][8][1]=     7; hi[9][8][1]=   12; gi[9][8][2]=  -8; hi[9][8][2]= -21;
	gi[9][8][3]=    -5; hi[9][8][3]=  -12; gi[9][8][4]=   9; hi[9][8][4]=  -7;
	gi[9][8][5]=     7; hi[9][8][5]=    2; gi[9][8][6]= -10; hi[9][8][6]=  18;
	gi[9][8][7]=     7; hi[9][8][7]=    3; gi[9][8][8]=   2; hi[9][8][8]= -11;
	gi[9][9][0]=     5;
	gi[9][9][1]=   -21; hi[9][9][1]=  -27; gi[9][9][2]=   1; hi[9][9][2]=  17;
	gi[9][9][3]=   -11; hi[9][9][3]=   29; gi[9][9][4]=   3; hi[9][9][4]=  -9;
	gi[9][9][5]=    16; hi[9][9][5]=    4; gi[9][9][6]=  -3; hi[9][9][6]=   9;
	gi[9][9][7]=    -4; hi[9][9][7]=    6; gi[9][9][8]=  -3; hi[9][9][8]=   1;
	gi[9][9][9]=    -4; hi[9][9][9]=    8;
	gi[9][10][0]=   -3;
	gi[9][10][1]=   11; hi[9][10][1]=   5; gi[9][10][2]=  1; hi[9][10][2]=  1;
	gi[9][10][3]=    2; hi[9][10][3]= -20; gi[9][10][4]= -5; hi[9][10][4]= -1;
	gi[9][10][5]=   -1; hi[9][10][5]=  -6; gi[9][10][6]=  8; hi[9][10][6]=  6;
	gi[9][10][7]=   -1; hi[9][10][7]=  -4; gi[9][10][8]= -3; hi[9][10][8]= -2;
	gi[9][10][9]=    5; hi[9][10][9]=   0; gi[9][10][10]=-2; hi[9][10][10]=-2;

/* DGRF1950 */

	gi[10][1][0]=-30554;
	gi[10][1][1]= -2250; hi[10][1][1]= 5815;
	gi[10][2][0]= -1341;
	gi[10][2][1]=  2998; hi[10][2][1]=-1810; gi[10][2][2]=1576; hi[10][2][2]= 381;
	gi[10][3][0]=  1297;
	gi[10][3][1]= -1889; hi[10][3][1]= -476; gi[10][3][2]=1274; hi[10][3][2]= 206;
	gi[10][3][3]=   896; hi[10][3][3]=  -46;
	gi[10][4][0]=   954;
	gi[10][4][1]=   792; hi[10][4][1]=  136; gi[10][4][2]= 528; hi[10][4][2]=-278;
	gi[10][4][3]=  -408; hi[10][4][3]=  -37; gi[10][4][4]= 303; hi[10][4][4]=-210;
	gi[10][5][0]=  -240;
	gi[10][5][1]=   349; hi[10][5][1]=    3; gi[10][5][2]= 211; hi[10][5][2]= 103;
	gi[10][5][3]=   -20; hi[10][5][3]=  -87; gi[10][5][4]=-147; hi[10][5][4]=-122;
	gi[10][5][5]=   -76; hi[10][5][5]=   80;
	gi[10][6][0]=    54;
	gi[10][6][1]=    57; hi[10][6][1]=   -1; gi[10][6][2]=   4; hi[10][6][2]=  99;
	gi[10][6][3]=  -247; hi[10][6][3]=   33; gi[10][6][4]= -16; hi[10][6][4]= -12;
	gi[10][6][5]=    12; hi[10][6][5]=  -12; gi[10][6][6]=-105; hi[10][6][6]= -30;
	gi[10][7][0]=    65;
	gi[10][7][1]=   -55; hi[10][7][1]=  -35; gi[10][7][2]=   2; hi[10][7][2]= -17;
	gi[10][7][3]=     1; hi[10][7][3]=    0; gi[10][7][4]= -40; hi[10][7][4]=  10;
	gi[10][7][5]=    -7; hi[10][7][5]=   36; gi[10][7][6]=   5; hi[10][7][6]= -18;
	gi[10][7][7]=    19; hi[10][7][7]=  -16;
	gi[10][8][0]=    22;
	gi[10][8][1]=    15; hi[10][8][1]=    5; gi[10][8][2]=  -4; hi[10][8][2]= -22;
	gi[10][8][3]=    -1; hi[10][8][3]=    0; gi[10][8][4]=  11; hi[10][8][4]= -21;
	gi[10][8][5]=    15; hi[10][8][5]=   -8; gi[10][8][6]= -13; hi[10][8][6]=  17;
	gi[10][8][7]=     5; hi[10][8][7]=   -4; gi[10][8][8]=  -1; hi[10][8][8]= -17;
	gi[10][9][0]=     3;
	gi[10][9][1]=    -7; hi[10][9][1]=  -24; gi[10][9][2]=  -1; hi[10][9][2]=  19;
	gi[10][9][3]=   -25; hi[10][9][3]=   12; gi[10][9][4]=  10; hi[10][9][4]=   2;
	gi[10][9][5]=     5; hi[10][9][5]=    2; gi[10][9][6]=  -5; hi[10][9][6]=   8;
	gi[10][9][7]=    -2; hi[10][9][7]=    8; gi[10][9][8]=   3; hi[10][9][8]= -11;
	gi[10][9][9]=     8; hi[10][9][9]=   -7;
	gi[10][10][0]=   -8;
	gi[10][10][1]=    4; hi[10][10][1]=  13; gi[10][10][2]= -1; hi[10][10][2]= -2;
	gi[10][10][3]=   13; hi[10][10][3]= -10; gi[10][10][4]= -4; hi[10][10][4]=  2;
	gi[10][10][5]=    4; hi[10][10][5]=  -3; gi[10][10][6]= 12; hi[10][10][6]=  6;
	gi[10][10][7]=    3; hi[10][10][7]=  -3; gi[10][10][8]=  2; hi[10][10][8]=  6;
	gi[10][10][9]=   10; hi[10][10][9]=  11; gi[10][10][10]= 3; hi[10][10][10]= 8;

/* DGRF1955 */

	gi[11][1][0]=-30500;
	gi[11][1][1]= -2215; hi[11][1][1]= 5820;
	gi[11][2][0]= -1440;
	gi[11][2][1]=  3003; hi[11][2][1]=-1898; gi[11][2][2]=1581; hi[11][2][2]= 291;
	gi[11][3][0]=  1302;
	gi[11][3][1]= -1944; hi[11][3][1]= -462; gi[11][3][2]=1288; hi[11][3][2]= 216;
	gi[11][3][3]=   882; hi[11][3][3]=  -83;
	gi[11][4][0]=   958;
	gi[11][4][1]=   796; hi[11][4][1]=  133; gi[11][4][2]= 510; hi[11][4][2]=-274;
	gi[11][4][3]=  -397; hi[11][4][3]=  -23; gi[11][4][4]= 290; hi[11][4][4]=-230;
	gi[11][5][0]=  -229;
	gi[11][5][1]=   360; hi[11][5][1]=   15; gi[11][5][2]= 230; hi[11][5][2]= 110;
	gi[11][5][3]=   -23; hi[11][5][3]=  -98; gi[11][5][4]=-152; hi[11][5][4]=-121;
	gi[11][5][5]=   -69; hi[11][5][5]=   78;
	gi[11][6][0]=    47;
	gi[11][6][1]=    57; hi[11][6][1]=   -9; gi[11][6][2]=   3; hi[11][6][2]=  96;
	gi[11][6][3]=  -247; hi[11][6][3]=   48; gi[11][6][4]=  -8; hi[11][6][4]= -16;
	gi[11][6][5]=     7; hi[11][6][5]=  -12; gi[11][6][6]=-107; hi[11][6][6]= -24;
	gi[11][7][0]=    65;
	gi[11][7][1]=   -56; hi[11][7][1]=  -50; gi[11][7][2]=   2; hi[11][7][2]= -24;
	gi[11][7][3]=    10; hi[11][7][3]=   -4; gi[11][7][4]= -32; hi[11][7][4]=   8;
	gi[11][7][5]=   -11; hi[11][7][5]=   28; gi[11][7][6]=   9; hi[11][7][6]= -20;
	gi[11][7][7]=    18; hi[11][7][7]=  -18;
	gi[11][8][0]=    11;
	gi[11][8][1]=     9; hi[11][8][1]=   10; gi[11][8][2]=  -6; hi[11][8][2]= -15;
	gi[11][8][3]=   -14; hi[11][8][3]=    5; gi[11][8][4]=   6; hi[11][8][4]= -23;
	gi[11][8][5]=    10; hi[11][8][5]=    3; gi[11][8][6]=  -7; hi[11][8][6]=  23;
	gi[11][8][7]=     6; hi[11][8][7]=   -4; gi[11][8][8]=   9; hi[11][8][8]= -13;
	gi[11][9][0]=     4;
	gi[11][9][1]=     9; hi[11][9][1]=  -11; gi[11][9][2]=  -4; hi[11][9][2]=  12;
	gi[11][9][3]=    -5; hi[11][9][3]=    7; gi[11][9][4]=   2; hi[11][9][4]=   6;
	gi[11][9][5]=     4; hi[11][9][5]=   -2; gi[11][9][6]=   1; hi[11][9][6]=  10;
	gi[11][9][7]=     2; hi[11][9][7]=    7; gi[11][9][8]=   2; hi[11][9][8]=  -6;
	gi[11][9][9]=     5; hi[11][9][9]=    5;
	gi[11][10][0]=   -3;
	gi[11][10][1]=   -5; hi[11][10][1]=  -4; gi[11][10][2]= -1; hi[11][10][2]=  0;
	gi[11][10][3]=    2; hi[11][10][3]=  -8; gi[11][10][4]= -3; hi[11][10][4]= -2;
	gi[11][10][5]=    7; hi[11][10][5]=  -4; gi[11][10][6]=  4; hi[11][10][6]=  1;
	gi[11][10][7]=   -2; hi[11][10][7]=  -3; gi[11][10][8]=  6; hi[11][10][8]=  7;
	gi[11][10][9]=   -2; hi[11][10][9]=  -1; gi[11][10][10]= 0; hi[11][10][10]=-3;

/* DGRF1960 */

	gi[12][1][0]=-30421;
	gi[12][1][1]= -2169; hi[12][1][1]= 5791;
	gi[12][2][0]= -1555;
	gi[12][2][1]=  3002; hi[12][2][1]=-1967; gi[12][2][2]=1590; hi[12][2][2]= 206;
	gi[12][3][0]=  1302;
	gi[12][3][1]= -1992; hi[12][3][1]= -414; gi[12][3][2]=1289; hi[12][3][2]= 224;
	gi[12][3][3]=   878; hi[12][3][3]= -130;
	gi[12][4][0]=   957;
	gi[12][4][1]=   800; hi[12][4][1]=  135; gi[12][4][2]= 504; hi[12][4][2]=-278;
	gi[12][4][3]=  -394; hi[12][4][3]=    3; gi[12][4][4]= 269; hi[12][4][4]=-255;
	gi[12][5][0]=  -222;
	gi[12][5][1]=   362; hi[12][5][1]=   16; gi[12][5][2]= 242; hi[12][5][2]= 125;
	gi[12][5][3]=   -26; hi[12][5][3]= -117; gi[12][5][4]=-156; hi[12][5][4]=-114;
	gi[12][5][5]=   -63; hi[12][5][5]=   81;
	gi[12][6][0]=    46;
	gi[12][6][1]=    58; hi[12][6][1]=  -10; gi[12][6][2]=   1; hi[12][6][2]=  99;
	gi[12][6][3]=  -237; hi[12][6][3]=   60; gi[12][6][4]=  -1; hi[12][6][4]= -20;
	gi[12][6][5]=    -2; hi[12][6][5]=  -11; gi[12][6][6]=-113; hi[12][6][6]= -17;
	gi[12][7][0]=    67;
	gi[12][7][1]=   -56; hi[12][7][1]=  -55; gi[12][7][2]=   5; hi[12][7][2]= -28;
	gi[12][7][3]=    15; hi[12][7][3]=   -6; gi[12][7][4]= -32; hi[12][7][4]=   7;
	gi[12][7][5]=    -7; hi[12][7][5]=   23; gi[12][7][6]=  17; hi[12][7][6]= -18;
	gi[12][7][7]=     8; hi[12][7][7]=  -17;
	gi[12][8][0]=    15;
	gi[12][8][1]=     6; hi[12][8][1]=   11; gi[12][8][2]=  -4; hi[12][8][2]= -14;
	gi[12][8][3]=   -11; hi[12][8][3]=    7; gi[12][8][4]=   2; hi[12][8][4]= -18;
	gi[12][8][5]=    10; hi[12][8][5]=    4; gi[12][8][6]=  -5; hi[12][8][6]=  23;
	gi[12][8][7]=    10; hi[12][8][7]=    1; gi[12][8][8]=   8; hi[12][8][8]= -20;
	gi[12][9][0]=     4;
	gi[12][9][1]=     6; hi[12][9][1]=  -18; gi[12][9][2]=   0; hi[12][9][2]=  12;
	gi[12][9][3]=    -9; hi[12][9][3]=    2; gi[12][9][4]=   1; hi[12][9][4]=   0;
	gi[12][9][5]=     4; hi[12][9][5]=   -3; gi[12][9][6]=  -1; hi[12][9][6]=   9;
	gi[12][9][7]=    -2; hi[12][9][7]=    8; gi[12][9][8]=   3; hi[12][9][8]=   0;
	gi[12][9][9]=    -1; hi[12][9][9]=    5;
	gi[12][10][0]=    1;
	gi[12][10][1]=   -3; hi[12][10][1]=   4; gi[12][10][2]=  4; hi[12][10][2]=  1;
	gi[12][10][3]=    0; hi[12][10][3]=   0; gi[12][10][4]= -1; hi[12][10][4]=  2;
	gi[12][10][5]=    4; hi[12][10][5]=  -5; gi[12][10][6]=  6; hi[12][10][6]=  1;
	gi[12][10][7]=    1; hi[12][10][7]=  -1; gi[12][10][8]= -1; hi[12][10][8]=  6;
	gi[12][10][9]=    2; hi[12][10][9]=   0; gi[12][10][10]= 0; hi[12][10][10]=-7;

/* DGRF1965 */

	gi[13][1][0]=-30334;
	gi[13][1][1]= -2119; hi[13][1][1]= 5776;
	gi[13][2][0]= -1662;
	gi[13][2][1]=  2997; hi[13][2][1]=-2016; gi[13][2][2]=1594; hi[13][2][2]= 114;
	gi[13][3][0]=  1297;
	gi[13][3][1]= -2038; hi[13][3][1]= -404; gi[13][3][2]=1292; hi[13][3][2]= 240;
	gi[13][3][3]=   856; hi[13][3][3]= -165;
	gi[13][4][0]=   957;
	gi[13][4][1]=   804; hi[13][4][1]=  148; gi[13][4][2]= 479; hi[13][4][2]=-269;
	gi[13][4][3]=  -390; hi[13][4][3]=   13; gi[13][4][4]= 252; hi[13][4][4]=-269;
	gi[13][5][0]=  -219;
	gi[13][5][1]=   358; hi[13][5][1]=   19; gi[13][5][2]= 254; hi[13][5][2]= 128;
	gi[13][5][3]=   -31; hi[13][5][3]= -126; gi[13][5][4]=-157; hi[13][5][4]= -97;
	gi[13][5][5]=   -62; hi[13][5][5]=   81;
	gi[13][6][0]=    45;
	gi[13][6][1]=    61; hi[13][6][1]=  -11; gi[13][6][2]=   8; hi[13][6][2]= 100;
	gi[13][6][3]=  -228; hi[13][6][3]=   68; gi[13][6][4]=   4; hi[13][6][4]= -32;
	gi[13][6][5]=     1; hi[13][6][5]=   -8; gi[13][6][6]=-111; hi[13][6][6]=  -7;
	gi[13][7][0]=    75;
	gi[13][7][1]=   -57; hi[13][7][1]=  -61; gi[13][7][2]=   4; hi[13][7][2]= -27;
	gi[13][7][3]=    13; hi[13][7][3]=   -2; gi[13][7][4]= -26; hi[13][7][4]=   6;
	gi[13][7][5]=    -6; hi[13][7][5]=   26; gi[13][7][6]=  13; hi[13][7][6]= -23;
	gi[13][7][7]=     1; hi[13][7][7]=  -12;
	gi[13][8][0]=    13;
	gi[13][8][1]=     5; hi[13][8][1]=    7; gi[13][8][2]=  -4; hi[13][8][2]= -12;
	gi[13][8][3]=   -14; hi[13][8][3]=    9; gi[13][8][4]=   0; hi[13][8][4]= -16;
	gi[13][8][5]=     8; hi[13][8][5]=    4; gi[13][8][6]=  -1; hi[13][8][6]=  24;
	gi[13][8][7]=    11; hi[13][8][7]=   -3; gi[13][8][8]=   4; hi[13][8][8]= -17;
	gi[13][9][0]=     8;
	gi[13][9][1]=    10; hi[13][9][1]=  -22; gi[13][9][2]=   2; hi[13][9][2]=  15;
	gi[13][9][3]=   -13; hi[13][9][3]=    7; gi[13][9][4]=  10; hi[13][9][4]=  -4;
	gi[13][9][5]=    -1; hi[13][9][5]=   -5; gi[13][9][6]=  -1; hi[13][9][6]=  10;
	gi[13][9][7]=     5; hi[13][9][7]=   10; gi[13][9][8]=   1; hi[13][9][8]=  -4;
	gi[13][9][9]=    -2; hi[13][9][9]=    1;
	gi[13][10][0]=   -2;
	gi[13][10][1]=   -3; hi[13][10][1]=   2; gi[13][10][2]=  2; hi[13][10][2]=  1;
	gi[13][10][3]=   -5; hi[13][10][3]=   2; gi[13][10][4]= -2; hi[13][10][4]=  6;
	gi[13][10][5]=    4; hi[13][10][5]=  -4; gi[13][10][6]=  4; hi[13][10][6]=  0;
	gi[13][10][7]=    0; hi[13][10][7]=  -2; gi[13][10][8]=  2; hi[13][10][8]=  3;
	gi[13][10][9]=    2; hi[13][10][9]=   0; gi[13][10][10]= 0; hi[13][10][10]=-6;

/* DGRF1970 */

	gi[14][1][0]=-30220;
	gi[14][1][1]= -2068; hi[14][1][1]= 5737;
	gi[14][2][0]= -1781;
	gi[14][2][1]=  3000; hi[14][2][1]=-2047; gi[14][2][2]=1611; hi[14][2][2]=  25;
	gi[14][3][0]=  1287;
	gi[14][3][1]= -2091; hi[14][3][1]= -366; gi[14][3][2]=1278; hi[14][3][2]= 251;
	gi[14][3][3]=   838; hi[14][3][3]= -196;
	gi[14][4][0]=   952;
	gi[14][4][1]=   800; hi[14][4][1]=  167; gi[14][4][2]= 461; hi[14][4][2]=-266;
	gi[14][4][3]=  -395; hi[14][4][3]=   26; gi[14][4][4]= 234; hi[14][4][4]=-279;
	gi[14][5][0]=  -216;
	gi[14][5][1]=   359; hi[14][5][1]=   26; gi[14][5][2]= 262; hi[14][5][2]= 139;
	gi[14][5][3]=   -42; hi[14][5][3]= -139; gi[14][5][4]=-160; hi[14][5][4]= -91;
	gi[14][5][5]=   -56; hi[14][5][5]=   83;
	gi[14][6][0]=    43;
	gi[14][6][1]=    64; hi[14][6][1]=  -12; gi[14][6][2]=  15; hi[14][6][2]= 100;
	gi[14][6][3]=  -212; hi[14][6][3]=   72; gi[14][6][4]=   2; hi[14][6][4]= -37;
	gi[14][6][5]=     3; hi[14][6][5]=   -6; gi[14][6][6]=-112; hi[14][6][6]=   1;
	gi[14][7][0]=    72;
	gi[14][7][1]=   -57; hi[14][7][1]=  -70; gi[14][7][2]=   1; hi[14][7][2]= -27;
	gi[14][7][3]=    14; hi[14][7][3]=   -4; gi[14][7][4]= -22; hi[14][7][4]=   8;
	gi[14][7][5]=    -2; hi[14][7][5]=   23; gi[14][7][6]=  13; hi[14][7][6]= -23;
	gi[14][7][7]=    -2; hi[14][7][7]=  -11;
	gi[14][8][0]=    14;
	gi[14][8][1]=     6; hi[14][8][1]=    7; gi[14][8][2]=  -2; hi[14][8][2]= -15;
	gi[14][8][3]=   -13; hi[14][8][3]=    6; gi[14][8][4]=  -3; hi[14][8][4]= -17;
	gi[14][8][5]=     5; hi[14][8][5]=    6; gi[14][8][6]=   0; hi[14][8][6]=  21;
	gi[14][8][7]=    11; hi[14][8][7]=   -6; gi[14][8][8]=   3; hi[14][8][8]= -16;
	gi[14][9][0]=     8;
	gi[14][9][1]=    10; hi[14][9][1]=  -21; gi[14][9][2]=   2; hi[14][9][2]=  16;
	gi[14][9][3]=   -12; hi[14][9][3]=    6; gi[14][9][4]=  10; hi[14][9][4]=  -4;
	gi[14][9][5]=    -1; hi[14][9][5]=   -5; gi[14][9][6]=   0; hi[14][9][6]=  10;
	gi[14][9][7]=     3; hi[14][9][7]=   11; gi[14][9][8]=   1; hi[14][9][8]=  -2;
	gi[14][9][9]=    -1; hi[14][9][9]=    1;
	gi[14][10][0]=   -3;
	gi[14][10][1]=   -3; hi[14][10][1]=   1; gi[14][10][2]=  2; hi[14][10][2]=  1;
	gi[14][10][3]=   -5; hi[14][10][3]=   3; gi[14][10][4]= -1; hi[14][10][4]=  4;
	gi[14][10][5]=    6; hi[14][10][5]=  -4; gi[14][10][6]=  4; hi[14][10][6]=  0;
	gi[14][10][7]=    1; hi[14][10][7]=  -1; gi[14][10][8]=  0; hi[14][10][8]=  3;
	gi[14][10][9]=    3; hi[14][10][9]=   1; gi[14][10][10]=-1; hi[14][10][10]=-4;

/* DGRF1975 */

	gi[15][1][0]=-30100;
	gi[15][1][1]= -2013; hi[15][1][1]= 5675;
	gi[15][2][0]= -1902;
	gi[15][2][1]=  3010; hi[15][2][1]=-2067; gi[15][2][2]=1632; hi[15][2][2]= -68;
	gi[15][3][0]=  1276;
	gi[15][3][1]= -2144; hi[15][3][1]= -333; gi[15][3][2]=1260; hi[15][3][2]= 262;
	gi[15][3][3]=   830; hi[15][3][3]= -223;
	gi[15][4][0]=   946;
	gi[15][4][1]=   791; hi[15][4][1]=  191; gi[15][4][2]= 438; hi[15][4][2]=-265;
	gi[15][4][3]=  -405; hi[15][4][3]=   39; gi[15][4][4]= 216; hi[15][4][4]=-288;
	gi[15][5][0]=  -218;
	gi[15][5][1]=   356; hi[15][5][1]=   31; gi[15][5][2]= 264; hi[15][5][2]= 148;
	gi[15][5][3]=   -59; hi[15][5][3]= -152; gi[15][5][4]=-159; hi[15][5][4]= -83;
	gi[15][5][5]=   -49; hi[15][5][5]=   88;
	gi[15][6][0]=    45;
	gi[15][6][1]=    66; hi[15][6][1]=  -13; gi[15][6][2]=  28; hi[15][6][2]=  99;
	gi[15][6][3]=  -198; hi[15][6][3]=   75; gi[15][6][4]=   1; hi[15][6][4]= -41;
	gi[15][6][5]=     6; hi[15][6][5]=   -4; gi[15][6][6]=-111; hi[15][6][6]=  11;
	gi[15][7][0]=    71;
	gi[15][7][1]=   -56; hi[15][7][1]=  -77; gi[15][7][2]=   1; hi[15][7][2]= -26;
	gi[15][7][3]=    16; hi[15][7][3]=   -5; gi[15][7][4]= -14; hi[15][7][4]=  10;
	gi[15][7][5]=     0; hi[15][7][5]=   22; gi[15][7][6]=  12; hi[15][7][6]= -23;
	gi[15][7][7]=    -5; hi[15][7][7]=  -12;
	gi[15][8][0]=    14;
	gi[15][8][1]=     6; hi[15][8][1]=    6; gi[15][8][2]=  -1; hi[15][8][2]= -16;
	gi[15][8][3]=   -12; hi[15][8][3]=    4; gi[15][8][4]=  -8; hi[15][8][4]= -19;
	gi[15][8][5]=     4; hi[15][8][5]=    6; gi[15][8][6]=   0; hi[15][8][6]=  18;
	gi[15][8][7]=    10; hi[15][8][7]=  -10; gi[15][8][8]=   1; hi[15][8][8]= -17;
	gi[15][9][0]=     7;
	gi[15][9][1]=    10; hi[15][9][1]=  -21; gi[15][9][2]=   2; hi[15][9][2]=  16;
	gi[15][9][3]=   -12; hi[15][9][3]=    7; gi[15][9][4]=  10; hi[15][9][4]=  -4;
	gi[15][9][5]=    -1; hi[15][9][5]=   -5; gi[15][9][6]=  -1; hi[15][9][6]=  10;
	gi[15][9][7]=     4; hi[15][9][7]=   11; gi[15][9][8]=   1; hi[15][9][8]=  -3;
	gi[15][9][9]=    -2; hi[15][9][9]=    1;
	gi[15][10][0]=   -3;
	gi[15][10][1]=   -3; hi[15][10][1]=   1; gi[15][10][2]=  2; hi[15][10][2]=  1;
	gi[15][10][3]=   -5; hi[15][10][3]=   3; gi[15][10][4]= -2; hi[15][10][4]=  4;
	gi[15][10][5]=    5; hi[15][10][5]=  -4; gi[15][10][6]=  4; hi[15][10][6]= -1;
	gi[15][10][7]=    1; hi[15][10][7]=  -1; gi[15][10][8]=  0; hi[15][10][8]=  3;
	gi[15][10][9]=    3; hi[15][10][9]=   1; gi[15][10][10]=-1; hi[15][10][10]=-5;

/* DGRF1980 */

	gi[16][1][0]=-29992;
	gi[16][1][1]= -1956; hi[16][1][1]= 5604;
	gi[16][2][0]= -1997;
	gi[16][2][1]=  3027; hi[16][2][1]=-2129; gi[16][2][2]=1663; hi[16][2][2]=-200;
	gi[16][3][0]=  1281;
	gi[16][3][1]= -2180; hi[16][3][1]= -336; gi[16][3][2]=1251; hi[16][3][2]= 271;
	gi[16][3][3]=   833; hi[16][3][3]= -252;
	gi[16][4][0]=   938;
	gi[16][4][1]=   782; hi[16][4][1]=  212; gi[16][4][2]= 398; hi[16][4][2]=-257;
	gi[16][4][3]=  -419; hi[16][4][3]=   53; gi[16][4][4]= 199; hi[16][4][4]=-297;
	gi[16][5][0]=  -218;
	gi[16][5][1]=   357; hi[16][5][1]=   46; gi[16][5][2]= 261; hi[16][5][2]= 150;
	gi[16][5][3]=   -74; hi[16][5][3]= -151; gi[16][5][4]=-162; hi[16][5][4]= -78;
	gi[16][5][5]=   -48; hi[16][5][5]=   92;
	gi[16][6][0]=    48;
	gi[16][6][1]=    66; hi[16][6][1]=  -15; gi[16][6][2]=  42; hi[16][6][2]=  93;
	gi[16][6][3]=  -192; hi[16][6][3]=   71; gi[16][6][4]=   4; hi[16][6][4]= -43;
	gi[16][6][5]=    14; hi[16][6][5]=   -2; gi[16][6][6]=-108; hi[16][6][6]=  17;
	gi[16][7][0]=    72;
	gi[16][7][1]=   -59; hi[16][7][1]=  -82; gi[16][7][2]=   2; hi[16][7][2]= -27;
	gi[16][7][3]=    21; hi[16][7][3]=   -5; gi[16][7][4]= -12; hi[16][7][4]=  16;
	gi[16][7][5]=     1; hi[16][7][5]=   18; gi[16][7][6]=  11; hi[16][7][6]= -23;
	gi[16][7][7]=    -2; hi[16][7][7]=  -10;
	gi[16][8][0]=    18;
	gi[16][8][1]=     6; hi[16][8][1]=    7; gi[16][8][2]=   0; hi[16][8][2]= -18;
	gi[16][8][3]=   -11; hi[16][8][3]=    4; gi[16][8][4]=  -7; hi[16][8][4]= -22;
	gi[16][8][5]=     4; hi[16][8][5]=    9; gi[16][8][6]=   3; hi[16][8][6]=  16;
	gi[16][8][7]=     6; hi[16][8][7]=  -13; gi[16][8][8]=  -1; hi[16][8][8]= -15;
	gi[16][9][0]=     5;
	gi[16][9][1]=    10; hi[16][9][1]=  -21; gi[16][9][2]=   1; hi[16][9][2]=  16;
	gi[16][9][3]=   -12; hi[16][9][3]=    9; gi[16][9][4]=   9; hi[16][9][4]=  -5;
	gi[16][9][5]=    -3; hi[16][9][5]=   -6; gi[16][9][6]=  -1; hi[16][9][6]=   9;
	gi[16][9][7]=     7; hi[16][9][7]=   10; gi[16][9][8]=   2; hi[16][9][8]=  -6;
	gi[16][9][9]=    -5; hi[16][9][9]=    2;
	gi[16][10][0]=   -4;
	gi[16][10][1]=   -4; hi[16][10][1]=   1; gi[16][10][2]=  2; hi[16][10][2]=  0;
	gi[16][10][3]=   -5; hi[16][10][3]=   3; gi[16][10][4]= -2; hi[16][10][4]=  6;
	gi[16][10][5]=    5; hi[16][10][5]=  -4; gi[16][10][6]=  3; hi[16][10][6]=  0;
	gi[16][10][7]=    1; hi[16][10][7]=  -1; gi[16][10][8]=  2; hi[16][10][8]=  4;
	gi[16][10][9]=    3; hi[16][10][9]=   0; gi[16][10][10]= 0; hi[16][10][10]=-6;

/* DGRF1985 */

	gi[17][1][0]=-29873;
	gi[17][1][1]= -1905; hi[17][1][1]= 5500;
	gi[17][2][0]= -2072;
	gi[17][2][1]=  3044; hi[17][2][1]=-2197; gi[17][2][2]=1687; hi[17][2][2]=-306;
	gi[17][3][0]=  1296;
	gi[17][3][1]= -2208; hi[17][3][1]= -310; gi[17][3][2]=1247; hi[17][3][2]= 284;
	gi[17][3][3]=   829; hi[17][3][3]= -297;
	gi[17][4][0]=   936;
	gi[17][4][1]=   780; hi[17][4][1]=  232; gi[17][4][2]= 361; hi[17][4][2]=-249;
	gi[17][4][3]=  -424; hi[17][4][3]=   69; gi[17][4][4]= 170; hi[17][4][4]=-297;
	gi[17][5][0]=  -214;
	gi[17][5][1]=   355; hi[17][5][1]=   47; gi[17][5][2]= 253; hi[17][5][2]= 150;
	gi[17][5][3]=   -93; hi[17][5][3]= -154; gi[17][5][4]=-164; hi[17][5][4]= -75;
	gi[17][5][5]=   -46; hi[17][5][5]=   95;
	gi[17][6][0]=    53;
	gi[17][6][1]=    65; hi[17][6][1]=  -16; gi[17][6][2]=  51; hi[17][6][2]=  88;
	gi[17][6][3]=  -185; hi[17][6][3]=   69; gi[17][6][4]=   4; hi[17][6][4]= -48;
	gi[17][6][5]=    16; hi[17][6][5]=   -1; gi[17][6][6]=-102; hi[17][6][6]=  21;
	gi[17][7][0]=    74;
	gi[17][7][1]=   -62; hi[17][7][1]=  -83; gi[17][7][2]=   3; hi[17][7][2]= -27;
	gi[17][7][3]=    24; hi[17][7][3]=   -2; gi[17][7][4]=  -6; hi[17][7][4]=  20;
	gi[17][7][5]=     4; hi[17][7][5]=   17; gi[17][7][6]=  10; hi[17][7][6]= -23;
	gi[17][7][7]=     0; hi[17][7][7]=   -7;
	gi[17][8][0]=    21;
	gi[17][8][1]=     6; hi[17][8][1]=    8; gi[17][8][2]=   0; hi[17][8][2]= -19;
	gi[17][8][3]=   -11; hi[17][8][3]=    5; gi[17][8][4]=  -9; hi[17][8][4]= -23;
	gi[17][8][5]=     4; hi[17][8][5]=   11; gi[17][8][6]=   4; hi[17][8][6]=  14;
	gi[17][8][7]=     4; hi[17][8][7]=  -15; gi[17][8][8]=  -4; hi[17][8][8]= -11;
	gi[17][9][0]=     5;
	gi[17][9][1]=    10; hi[17][9][1]=  -21; gi[17][9][2]=   1; hi[17][9][2]=  15;
	gi[17][9][3]=   -12; hi[17][9][3]=    9; gi[17][9][4]=   9; hi[17][9][4]=  -6;
	gi[17][9][5]=    -3; hi[17][9][5]=   -6; gi[17][9][6]=  -1; hi[17][9][6]=   9;
	gi[17][9][7]=     7; hi[17][9][7]=    9; gi[17][9][8]=   1; hi[17][9][8]=  -7;
	gi[17][9][9]=    -5; hi[17][9][9]=    2;
	gi[17][10][0]=   -4;
	gi[17][10][1]=   -4; hi[17][10][1]=   1; gi[17][10][2]=  3; hi[17][10][2]=  0;
	gi[17][10][3]=   -5; hi[17][10][3]=   3; gi[17][10][4]= -2; hi[17][10][4]=  6;
	gi[17][10][5]=    5; hi[17][10][5]=  -4; gi[17][10][6]=  3; hi[17][10][6]=  0;
	gi[17][10][7]=    1; hi[17][10][7]=  -1; gi[17][10][8]=  2; hi[17][10][8]=  4;
	gi[17][10][9]=    3; hi[17][10][9]=   0; gi[17][10][10]= 0; hi[17][10][10]=-6;

/* DGRF1990 */

	gi[18][1][0]=-29775;
	gi[18][1][1]= -1848; hi[18][1][1]= 5406;
	gi[18][2][0]= -2131;
	gi[18][2][1]=  3059; hi[18][2][1]=-2279; gi[18][2][2]=1686; hi[18][2][2]=-373;
	gi[18][3][0]=  1314;
	gi[18][3][1]= -2239; hi[18][3][1]= -284; gi[18][3][2]=1248; hi[18][3][2]= 293;
	gi[18][3][3]=   802; hi[18][3][3]= -352;
	gi[18][4][0]=   939;
	gi[18][4][1]=   780; hi[18][4][1]=  247; gi[18][4][2]= 325; hi[18][4][2]=-240;
	gi[18][4][3]=  -423; hi[18][4][3]=   84; gi[18][4][4]= 141; hi[18][4][4]=-299;
	gi[18][5][0]=  -214;
	gi[18][5][1]=   353; hi[18][5][1]=   46; gi[18][5][2]= 245; hi[18][5][2]= 154;
	gi[18][5][3]=  -109; hi[18][5][3]= -153; gi[18][5][4]=-165; hi[18][5][4]= -69;
	gi[18][5][5]=   -36; hi[18][5][5]=   97;
	gi[18][6][0]=    61;
	gi[18][6][1]=    65; hi[18][6][1]=  -16; gi[18][6][2]=  59; hi[18][6][2]=  82;
	gi[18][6][3]=  -178; hi[18][6][3]=   69; gi[18][6][4]=   3; hi[18][6][4]= -52;
	gi[18][6][5]=    18; hi[18][6][5]=    1; gi[18][6][6]= -96; hi[18][6][6]=  24;
	gi[18][7][0]=    77;
	gi[18][7][1]=   -64; hi[18][7][1]=  -80; gi[18][7][2]=   2; hi[18][7][2]= -26;
	gi[18][7][3]=    26; hi[18][7][3]=    0; gi[18][7][4]=  -1; hi[18][7][4]=  21;
	gi[18][7][5]=     5; hi[18][7][5]=   17; gi[18][7][6]=   9; hi[18][7][6]= -23;
	gi[18][7][7]=     0; hi[18][7][7]=   -4;
	gi[18][8][0]=    23;
	gi[18][8][1]=     5; hi[18][8][1]=   10; gi[18][8][2]=  -1; hi[18][8][2]= -19;
	gi[18][8][3]=   -10; hi[18][8][3]=    6; gi[18][8][4]= -12; hi[18][8][4]= -22;
	gi[18][8][5]=     3; hi[18][8][5]=   12; gi[18][8][6]=   4; hi[18][8][6]=  12;
	gi[18][8][7]=     2; hi[18][8][7]=  -16; gi[18][8][8]=  -6; hi[18][8][8]= -10;
	gi[18][9][0]=     4;
	gi[18][9][1]=     9; hi[18][9][1]=  -20; gi[18][9][2]=   1; hi[18][9][2]=  15;
	gi[18][9][3]=   -12; hi[18][9][3]=   11; gi[18][9][4]=   9; hi[18][9][4]=  -7;
	gi[18][9][5]=    -4; hi[18][9][5]=   -7; gi[18][9][6]=  -2; hi[18][9][6]=   9;
	gi[18][9][7]=     7; hi[18][9][7]=    8; gi[18][9][8]=   1; hi[18][9][8]=  -7;
	gi[18][9][9]=    -6; hi[18][9][9]=    2;
	gi[18][10][0]=   -3;
	gi[18][10][1]=   -4; hi[18][10][1]=   2; gi[18][10][2]=  2; hi[18][10][2]=  1;
	gi[18][10][3]=   -5; hi[18][10][3]=   3; gi[18][10][4]= -2; hi[18][10][4]=  6;
	gi[18][10][5]=    4; hi[18][10][5]=  -4; gi[18][10][6]=  3; hi[18][10][6]=  0;
	gi[18][10][7]=    1; hi[18][10][7]=  -2; gi[18][10][8]=  3; hi[18][10][8]=  3;
	gi[18][10][9]=    3; hi[18][10][9]=  -1; gi[18][10][10]= 0; hi[18][10][10]=-6;

/* DGRF1995 */

	gi[19][1][0]=-29692;
	gi[19][1][1]= -1784; hi[19][1][1]= 5306;
	gi[19][2][0]= -2200;
	gi[19][2][1]=  3070; hi[19][2][1]=-2366; gi[19][2][2]=1681; hi[19][2][2]=-413;
	gi[19][3][0]=  1335;
	gi[19][3][1]= -2267; hi[19][3][1]= -262; gi[19][3][2]=1249; hi[19][3][2]= 302;
	gi[19][3][3]=   759; hi[19][3][3]= -427;
	gi[19][4][0]=   940;
	gi[19][4][1]=   780; hi[19][4][1]=  262; gi[19][4][2]= 290; hi[19][4][2]=-236;
	gi[19][4][3]=  -418; hi[19][4][3]=   97; gi[19][4][4]= 122; hi[19][4][4]=-306;
	gi[19][5][0]=  -214;
	gi[19][5][1]=   352; hi[19][5][1]=   46; gi[19][5][2]= 235; hi[19][5][2]= 165;
	gi[19][5][3]=  -118; hi[19][5][3]= -143; gi[19][5][4]=-166; hi[19][5][4]= -55;
	gi[19][5][5]=   -17; hi[19][5][5]=  107;
	gi[19][6][0]=    68;
	gi[19][6][1]=    67; hi[19][6][1]=  -17; gi[19][6][2]=  68; hi[19][6][2]=  72;
	gi[19][6][3]=  -170; hi[19][6][3]=   67; gi[19][6][4]=  -1; hi[19][6][4]= -58;
	gi[19][6][5]=    19; hi[19][6][5]=    1; gi[19][6][6]= -93; hi[19][6][6]=  36;
	gi[19][7][0]=    77;
	gi[19][7][1]=   -72; hi[19][7][1]=  -69; gi[19][7][2]=   1; hi[19][7][2]= -25;
	gi[19][7][3]=    28; hi[19][7][3]=    4; gi[19][7][4]=   5; hi[19][7][4]=  24;
	gi[19][7][5]=     4; hi[19][7][5]=   17; gi[19][7][6]=   8; hi[19][7][6]= -24;
	gi[19][7][7]=    -2; hi[19][7][7]=   -6;
	gi[19][8][0]=    25;
	gi[19][8][1]=     6; hi[19][8][1]=   11; gi[19][8][2]=  -6; hi[19][8][2]= -21;
	gi[19][8][3]=    -9; hi[19][8][3]=    8; gi[19][8][4]= -14; hi[19][8][4]= -23;
	gi[19][8][5]=     9; hi[19][8][5]=   15; gi[19][8][6]=   6; hi[19][8][6]=  11;
	gi[19][8][7]=    -5; hi[19][8][7]=  -16; gi[19][8][8]=  -7; hi[19][8][8]=  -4;
	gi[19][9][0]=     4;
	gi[19][9][1]=     9; hi[19][9][1]=  -20; gi[19][9][2]=   3; hi[19][9][2]=  15;
	gi[19][9][3]=   -10; hi[19][9][3]=   12; gi[19][9][4]=   8; hi[19][9][4]=  -6;
	gi[19][9][5]=    -8; hi[19][9][5]=   -8; gi[19][9][6]=  -1; hi[19][9][6]=   8;
	gi[19][9][7]=    10; hi[19][9][7]=    5; gi[19][9][8]=  -2; hi[19][9][8]=  -8;
	gi[19][9][9]=    -8; hi[19][9][9]=    3;
	gi[19][10][0]=   -3;
	gi[19][10][1]=   -6; hi[19][10][1]=   1; gi[19][10][2]=  2; hi[19][10][2]=  0;
	gi[19][10][3]=   -4; hi[19][10][3]=   4; gi[19][10][4]= -1; hi[19][10][4]=  5;
	gi[19][10][5]=    4; hi[19][10][5]=  -5; gi[19][10][6]=  2; hi[19][10][6]= -1;
	gi[19][10][7]=    2; hi[19][10][7]=  -2; gi[19][10][8]=  5; hi[19][10][8]=  1;
	gi[19][10][9]=    1; hi[19][10][9]=  -2; gi[19][10][10]= 0; hi[19][10][10]=-7;

/* DGRF2000 */

	gi[20][1][0]=-29619.4;
	gi[20][1][1]= -1728.2; hi[20][1][1]= 5186.1;
	gi[20][2][0]= -2267.7;
	gi[20][2][1]=  3068.4; hi[20][2][1]=-2481.6; gi[20][2][2]=1670.9; hi[20][2][2]=-458.0;
	gi[20][3][0]=  1339.6;
	gi[20][3][1]= -2288.0; hi[20][3][1]= -227.6; gi[20][3][2]=1252.1; hi[20][3][2]= 293.4;
	gi[20][3][3]=   714.5; hi[20][3][3]= -491.1;
	gi[20][4][0]=   932.3;
	gi[20][4][1]=   786.8; hi[20][4][1]=  272.6; gi[20][4][2]= 250.0; hi[20][4][2]=-231.9;
	gi[20][4][3]=  -403.0; hi[20][4][3]=  119.8; gi[20][4][4]= 111.3; hi[20][4][4]=-303.8;
	gi[20][5][0]=  -218.8;
	gi[20][5][1]=   351.4; hi[20][5][1]=   43.8; gi[20][5][2]= 222.3; hi[20][5][2]= 171.9;
	gi[20][5][3]=  -130.4; hi[20][5][3]= -133.1; gi[20][5][4]=-168.6; hi[20][5][4]= -39.3;
	gi[20][5][5]=   -12.9; hi[20][5][5]=  106.3;
	gi[20][6][0]=    72.3;
	gi[20][6][1]=    68.2; hi[20][6][1]=  -17.4; gi[20][6][2]=  74.2; hi[20][6][2]=  63.7;
	gi[20][6][3]=  -160.9; hi[20][6][3]=   65.1; gi[20][6][4]=  -5.9; hi[20][6][4]= -61.2;
	gi[20][6][5]=    16.9; hi[20][6][5]=    0.7; gi[20][6][6]= -90.4; hi[20][6][6]=  43.8;
	gi[20][7][0]=    79.0;
	gi[20][7][1]=   -74.0; hi[20][7][1]=  -64.6; gi[20][7][2]=  0.0; hi[20][7][2]= -24.2;
	gi[20][7][3]=    33.3; hi[20][7][3]=    6.2; gi[20][7][4]=  9.1; hi[20][7][4]=  24.0;
	gi[20][7][5]=     6.9; hi[20][7][5]=   14.8; gi[20][7][6]=  7.3; hi[20][7][6]= -25.4;
	gi[20][7][7]=    -1.2; hi[20][7][7]=   -5.8;
	gi[20][8][0]=    24.4;
	gi[20][8][1]=     6.6; hi[20][8][1]=   11.9; gi[20][8][2]=  -9.2; hi[20][8][2]= -21.5;
	gi[20][8][3]=    -7.9; hi[20][8][3]=    8.5; gi[20][8][4]= -16.6; hi[20][8][4]= -21.5;
	gi[20][8][5]=     9.1; hi[20][8][5]=   15.5; gi[20][8][6]=   7.0; hi[20][8][6]=  8.9;
	gi[20][8][7]=    -7.9; hi[20][8][7]=  -14.9; gi[20][8][8]=  -7.0; hi[20][8][8]= -2.1;
	gi[20][9][0]=     5.0;
	gi[20][9][1]=     9.4; hi[20][9][1]=  -19.7; gi[20][9][2]=   3.0; hi[20][9][2]=  13.4;
	gi[20][9][3]=    -8.4; hi[20][9][3]=   12.5; gi[20][9][4]=   6.3; hi[20][9][4]=  -6.2;
	gi[20][9][5]=    -8.9; hi[20][9][5]=   -8.4; gi[20][9][6]=  -1.5; hi[20][9][6]=   8.4;
	gi[20][9][7]=     9.3; hi[20][9][7]=    3.8; gi[20][9][8]=  -4.3; hi[20][9][8]=  -8.2;
	gi[20][9][9]=    -8.2; hi[20][9][9]=    4.8;
	gi[20][10][0]=   -2.6;
	gi[20][10][1]=   -6.0; hi[20][10][1]=   1.7; gi[20][10][2]=  1.7; hi[20][10][2]=  0.0;
	gi[20][10][3]=   -3.1; hi[20][10][3]=   4.0; gi[20][10][4]= -0.5; hi[20][10][4]=  4.9;
	gi[20][10][5]=    3.7; hi[20][10][5]=  -5.9; gi[20][10][6]=  1.0; hi[20][10][6]= -1.2;
	gi[20][10][7]=    2.0; hi[20][10][7]=  -2.9; gi[20][10][8]=  4.2; hi[20][10][8]=  0.2;
	gi[20][10][9]=    0.3; hi[20][10][9]=  -2.2; gi[20][10][10]=-1.1; hi[20][10][10]=-7.4;

/* DGRF2005 */

	gi[21][1][0]=-29554.63;
	gi[21][1][1]= -1669.05; hi[21][1][1]= 5077.99;
	gi[21][2][0]= -2337.24;
	gi[21][2][1]=  3047.69; hi[21][2][1]=-2594.50; gi[21][2][2]=1657.76; hi[21][2][2]=-515.43;
	gi[21][3][0]=  1336.30;
	gi[21][3][1]= -2305.83; hi[21][3][1]= -198.86; gi[21][3][2]=1246.39; hi[21][3][2]= 269.72;
	gi[21][3][3]=   672.51; hi[21][3][3]= -524.72;
	gi[21][4][0]=   920.55;
	gi[21][4][1]=   797.96; hi[21][4][1]=  282.07; gi[21][4][2]= 210.65; hi[21][4][2]=-225.23;
	gi[21][4][3]=  -379.86; hi[21][4][3]=  145.15; gi[21][4][4]= 100.00; hi[21][4][4]=-305.36;
	gi[21][5][0]=  -227.00;
	gi[21][5][1]=   354.41; hi[21][5][1]=   42.72; gi[21][5][2]= 208.95; hi[21][5][2]= 180.25;
	gi[21][5][3]=  -136.54; hi[21][5][3]= -123.45; gi[21][5][4]=-168.05; hi[21][5][4]= -19.57;
	gi[21][5][5]=   -13.55; hi[21][5][5]=  103.85;
	gi[21][6][0]=    73.60;
	gi[21][6][1]=    69.56; hi[21][6][1]=  -20.33; gi[21][6][2]=  76.74; hi[21][6][2]=  54.75;
	gi[21][6][3]=  -151.34; hi[21][6][3]=   63.63; gi[21][6][4]= -14.58; hi[21][6][4]= -63.53;
	gi[21][6][5]=    14.58; hi[21][6][5]=    0.24; gi[21][6][6]= -86.36; hi[21][6][6]=  50.94;
	gi[21][7][0]=    79.88;
	gi[21][7][1]=   -74.46; hi[21][7][1]=  -61.14; gi[21][7][2]= -1.65; hi[21][7][2]= -22.57;
	gi[21][7][3]=    38.73; hi[21][7][3]=    6.82; gi[21][7][4]= 12.30; hi[21][7][4]=  25.35;
	gi[21][7][5]=     9.37; hi[21][7][5]=   10.93; gi[21][7][6]=  5.42; hi[21][7][6]= -26.32;
	gi[21][7][7]=     1.94; hi[21][7][7]=   -4.64;
	gi[21][8][0]=    24.80;
	gi[21][8][1]=     7.62; hi[21][8][1]=   11.20; gi[21][8][2]= -11.73; hi[21][8][2]= -20.88;
	gi[21][8][3]=    -6.88; hi[21][8][3]=    9.83; gi[21][8][4]= -18.11; hi[21][8][4]= -19.71;
	gi[21][8][5]=    10.17; hi[21][8][5]=   16.22; gi[21][8][6]=   9.36; hi[21][8][6]=   7.61;
	gi[21][8][7]=   -11.25; hi[21][8][7]=  -12.76; gi[21][8][8]=  -4.87; hi[21][8][8]=  -0.06;
	gi[21][9][0]=     5.58;
	gi[21][9][1]=     9.76; hi[21][9][1]=  -20.11; gi[21][9][2]=   3.58; hi[21][9][2]=  12.69;
	gi[21][9][3]=    -6.94; hi[21][9][3]=   12.67; gi[21][9][4]=   5.01; hi[21][9][4]=  -6.72;
	gi[21][9][5]=   -10.76; hi[21][9][5]=   -8.16; gi[21][9][6]=  -1.25; hi[21][9][6]=   8.10;
	gi[21][9][7]=     8.76; hi[21][9][7]=    2.92; gi[21][9][8]=  -6.66; hi[21][9][8]=  -7.73;
	gi[21][9][9]=    -9.22; hi[21][9][9]=    6.01;
	gi[21][10][0]=   -2.17;
	gi[21][10][1]=   -6.12; hi[21][10][1]=   2.19; gi[21][10][2]=  1.42; hi[21][10][2]=  0.10;
	gi[21][10][3]=   -2.35; hi[21][10][3]=   4.46; gi[21][10][4]= -0.15; hi[21][10][4]=  4.76;
	gi[21][10][5]=    3.06; hi[21][10][5]=  -6.58; gi[21][10][6]=  0.29; hi[21][10][6]= -1.01;
	gi[21][10][7]=    2.06; hi[21][10][7]=  -3.47; gi[21][10][8]=  3.77; hi[21][10][8]= -0.86;
	gi[21][10][9]=   -0.21; hi[21][10][9]=  -2.31; gi[21][10][10]=-2.09; hi[21][10][10]=-7.93;

/* DGRF2010 */

	gi[22][1][0]=-29496.57;
	gi[22][1][1]= -1586.42; hi[22][1][1]= 4944.26;
	gi[22][2][0]= -2396.06;
	gi[22][2][1]=  3026.34; hi[22][2][1]=-2708.54; gi[22][2][2]=1668.17; hi[22][2][2]=-575.73;
	gi[22][3][0]=  1339.85;
	gi[22][3][1]= -2326.54; hi[22][3][1]= -160.40; gi[22][3][2]=1232.10; hi[22][3][2]= 251.75;
	gi[22][3][3]=   633.73; hi[22][3][3]= -537.03;
	gi[22][4][0]=   912.66;
	gi[22][4][1]=   808.97; hi[22][4][1]=  286.48; gi[22][4][2]= 166.58; hi[22][4][2]=-211.03;
	gi[22][4][3]=  -356.83; hi[22][4][3]=  164.46; gi[22][4][4]=  89.40; hi[22][4][4]=-309.72;
	gi[22][5][0]=  -230.87;
	gi[22][5][1]=   357.29; hi[22][5][1]=   44.58; gi[22][5][2]= 200.26; hi[22][5][2]= 189.01;
	gi[22][5][3]=  -141.05; hi[22][5][3]= -118.06; gi[22][5][4]=-163.17; hi[22][5][4]=  -0.01;
	gi[22][5][5]=    -8.03; hi[22][5][5]=  101.04;
	gi[22][6][0]=    72.78;
	gi[22][6][1]=    68.69; hi[22][6][1]=  -20.90; gi[22][6][2]=  75.92; hi[22][6][2]=  44.18;
	gi[22][6][3]=  -141.40; hi[22][6][3]=   61.54; gi[22][6][4]= -22.83; hi[22][6][4]= -66.26;
	gi[22][6][5]=    13.10; hi[22][6][5]=    3.02; gi[22][6][6]= -78.09; hi[22][6][6]=  55.40;
	gi[22][7][0]=    80.44;
	gi[22][7][1]=   -75.00; hi[22][7][1]=  -57.80; gi[22][7][2]=  -4.55; hi[22][7][2]= -21.20;
	gi[22][7][3]=    45.24; hi[22][7][3]=    6.54; gi[22][7][4]=  14.00; hi[22][7][4]=  24.96;
	gi[22][7][5]=    10.46; hi[22][7][5]=    7.03; gi[22][7][6]=   1.64; hi[22][7][6]= -27.61;
	gi[22][7][7]=     4.92; hi[22][7][7]=   -3.28;
	gi[22][8][0]=    24.41;
	gi[22][8][1]=     8.21; hi[22][8][1]=   10.84; gi[22][8][2]= -14.50; hi[22][8][2]= -20.03;
	gi[22][8][3]=    -5.59; hi[22][8][3]=   11.83; gi[22][8][4]= -19.34; hi[22][8][4]= -17.41;
	gi[22][8][5]=    11.61; hi[22][8][5]=   16.71; gi[22][8][6]=  10.85; hi[22][8][6]=   6.96;
	gi[22][8][7]=   -14.05; hi[22][8][7]=  -10.74; gi[22][8][8]=  -3.54; hi[22][8][8]=   1.64;
	gi[22][9][0]=     5.50;
	gi[22][9][1]=     9.45; hi[22][9][1]=  -20.54; gi[22][9][2]=   3.45; hi[22][9][2]=  11.51;
	gi[22][9][3]=    -5.27; hi[22][9][3]=   12.75; gi[22][9][4]=   3.13; hi[22][9][4]=  -7.14;
	gi[22][9][5]=   -12.38; hi[22][9][5]=   -7.42; gi[22][9][6]=  -0.76; hi[22][9][6]=   7.97;
	gi[22][9][7]=     8.43; hi[22][9][7]=    2.14; gi[22][9][8]=  -8.42; hi[22][9][8]=  -6.08;
	gi[22][9][9]=   -10.08; hi[22][9][9]=    7.01;
	gi[22][10][0]=   -1.94;
	gi[22][10][1]=   -6.24; hi[22][10][1]=   2.73; gi[22][10][2]=  0.89; hi[22][10][2]= -0.10;
	gi[22][10][3]=   -1.07; hi[22][10][3]=   4.71; gi[22][10][4]= -0.16; hi[22][10][4]=  4.44;
	gi[22][10][5]=    2.45; hi[22][10][5]=  -7.22; gi[22][10][6]= -0.33; hi[22][10][6]= -0.96;
	gi[22][10][7]=    2.13; hi[22][10][7]=  -3.95; gi[22][10][8]=  3.09; hi[22][10][8]= -1.99;
	gi[22][10][9]=   -1.03; hi[22][10][9]=  -1.97; gi[22][10][10]=-2.80; hi[22][10][10]=-8.31;

/* DGRF2015 */

	gi[23][1][0]=-29441.46;
	gi[23][1][1]= -1501.77; hi[23][1][1]= 4795.99;
	gi[23][2][0]= -2445.88;
	gi[23][2][1]=  3012.20; hi[23][2][1]=-2845.41; gi[23][2][2]=1676.35; hi[23][2][2]=-642.17;
	gi[23][3][0]=  1350.33;
	gi[23][3][1]= -2352.26; hi[23][3][1]= -115.29; gi[23][3][2]=1225.85; hi[23][3][2]= 245.04;
	gi[23][3][3]=   581.69; hi[23][3][3]= -538.70;
	gi[23][4][0]=   907.42;
	gi[23][4][1]=   813.68; hi[23][4][1]=  283.54; gi[23][4][2]= 120.49; hi[23][4][2]=-188.43;
	gi[23][4][3]=  -334.85; hi[23][4][3]=  180.95; gi[23][4][4]=  70.38; hi[23][4][4]=-329.23;
	gi[23][5][0]=  -232.91;
	gi[23][5][1]=   360.14; hi[23][5][1]=   46.98; gi[23][5][2]= 192.35; hi[23][5][2]= 196.98;
	gi[23][5][3]=  -140.94; hi[23][5][3]= -119.14; gi[23][5][4]=-157.40; hi[23][5][4]=  15.98;
	gi[23][5][5]=     4.30; hi[23][5][5]=  100.12;
	gi[23][6][0]=    69.55;
	gi[23][6][1]=    67.57; hi[23][6][1]=  -20.61; gi[23][6][2]=  72.79; hi[23][6][2]=  33.30;
	gi[23][6][3]=  -129.85; hi[23][6][3]=   58.74; gi[23][6][4]= -28.93; hi[23][6][4]= -66.64;
	gi[23][6][5]=    13.14; hi[23][6][5]=    7.35; gi[23][6][6]= -70.85; hi[23][6][6]=  62.41;
	gi[23][7][0]=    81.29;
	gi[23][7][1]=   -75.99; hi[23][7][1]=  -54.27; gi[23][7][2]= -6.79; hi[23][7][2]= -19.53;
	gi[23][7][3]=    51.82; hi[23][7][3]=    5.59; gi[23][7][4]= 15.07; hi[23][7][4]=  24.45;
	gi[23][7][5]=     9.32; hi[23][7][5]=    3.27; gi[23][7][6]= -2.88; hi[23][7][6]= -27.50;
	gi[23][7][7]=     6.61; hi[23][7][7]=   -2.32;
	gi[23][8][0]=    23.98;
	gi[23][8][1]=     8.89; hi[23][8][1]=   10.04; gi[23][8][2]= -16.78; hi[23][8][2]= -18.26;
	gi[23][8][3]=    -3.16; hi[23][8][3]=   13.18; gi[23][8][4]= -20.56; hi[23][8][4]= -14.60;
	gi[23][8][5]=    13.33; hi[23][8][5]=   16.16; gi[23][8][6]=  11.76; hi[23][8][6]=  5.69;
	gi[23][8][7]=   -15.98; hi[23][8][7]=   -9.10; gi[23][8][8]=  -2.02; hi[23][8][8]=  2.26;
	gi[23][9][0]=     5.33;
	gi[23][9][1]=     8.83; hi[23][9][1]=  -21.77; gi[23][9][2]=   3.02; hi[23][9][2]=  10.76;
	gi[23][9][3]=    -3.22; hi[23][9][3]=   11.74; gi[23][9][4]=   0.67; hi[23][9][4]=  -6.74;
	gi[23][9][5]=   -13.20; hi[23][9][5]=   -6.88; gi[23][9][6]=  -0.10; hi[23][9][6]=   7.79;
	gi[23][9][7]=     8.68; hi[23][9][7]=    1.04; gi[23][9][8]=  -9.06; hi[23][9][8]=  -3.89;
	gi[23][9][9]=   -10.54; hi[23][9][9]=    8.44;
	gi[23][10][0]=   -2.01;
	gi[23][10][1]=   -6.26; hi[23][10][1]=   3.28; gi[23][10][2]=  0.17; hi[23][10][2]= -0.40;
	gi[23][10][3]=    0.55; hi[23][10][3]=   4.55; gi[23][10][4]= -0.55; hi[23][10][4]=  4.40;
	gi[23][10][5]=    1.70; hi[23][10][5]=  -7.92; gi[23][10][6]= -0.67; hi[23][10][6]= -0.61;
	gi[23][10][7]=    2.13; hi[23][10][7]=  -4.16; gi[23][10][8]=  2.33; hi[23][10][8]= -2.85;
	gi[23][10][9]=   -1.80; hi[23][10][9]=  -1.12; gi[23][10][10]=-3.59; hi[23][10][10]=-8.72;

/* IGRF2020 */

	gi[24][1][0]=-29404.8;
	gi[24][1][1]= -1450.9; hi[24][1][1]= 4652.5;
	gi[24][2][0]= -2499.6;
	gi[24][2][1]=  2982.0; hi[24][2][1]=-2991.6; gi[24][2][2]=1677.0; hi[24][2][2]=-734.6;
	gi[24][3][0]=  1363.2;
	gi[24][3][1]= -2381.2; hi[24][3][1]=  -82.1; gi[24][3][2]=1236.2; hi[24][3][2]= 241.9;
	gi[24][3][3]=   525.7; hi[24][3][3]= -543.4;
	gi[24][4][0]=   903.0;
	gi[24][4][1]=   809.5; hi[24][4][1]=  281.9; gi[24][4][2]=  86.3; hi[24][4][2]=-158.4;
	gi[24][4][3]=  -309.4; hi[24][4][3]=  199.7; gi[24][4][4]=  48.0; hi[24][4][4]=-349.7;
	gi[24][5][0]=  -234.3;
	gi[24][5][1]=   363.2; hi[24][5][1]=   47.7; gi[24][5][2]= 187.8; hi[24][5][2]= 208.3;
	gi[24][5][3]=  -140.7; hi[24][5][3]= -121.2; gi[24][5][4]=-151.2; hi[24][5][4]=  32.3;
	gi[24][5][5]=    13.5; hi[24][5][5]=   98.9;
	gi[24][6][0]=    66.0;
	gi[24][6][1]=    65.5; hi[24][6][1]=  -19.1; gi[24][6][2]=  72.9; hi[24][6][2]=  25.1;
	gi[24][6][3]=  -121.5; hi[24][6][3]=   52.8; gi[24][6][4]= -36.2; hi[24][6][4]= -64.5;
	gi[24][6][5]=    13.5; hi[24][6][5]=    8.9; gi[24][6][6]= -64.7; hi[24][6][6]=  68.1;
	gi[24][7][0]=    80.6;
	gi[24][7][1]=   -76.7; hi[24][7][1]=  -51.5; gi[24][7][2]= -8.2; hi[24][7][2]= -16.9;
	gi[24][7][3]=    56.5; hi[24][7][3]=    2.2; gi[24][7][4]= 15.8; hi[24][7][4]=  23.5;
	gi[24][7][5]=     6.4; hi[24][7][5]=   -2.2; gi[24][7][6]= -7.2; hi[24][7][6]= -27.2;
	gi[24][7][7]=     9.8; hi[24][7][7]=   -1.8;
	gi[24][8][0]=    23.7;
	gi[24][8][1]=     9.7; hi[24][8][1]=    8.4; gi[24][8][2]= -17.6; hi[24][8][2]= -15.3;
	gi[24][8][3]=    -0.5; hi[24][8][3]=   12.8; gi[24][8][4]= -21.1; hi[24][8][4]= -11.7;
	gi[24][8][5]=    15.3; hi[24][8][5]=   14.9; gi[24][8][6]=  13.7; hi[24][8][6]=   3.6;
	gi[24][8][7]=   -16.5; hi[24][8][7]=   -6.9; gi[24][8][8]=  -0.3; hi[24][8][8]=   2.8;
	gi[24][9][0]=     5.0;
	gi[24][9][1]=     8.4; hi[24][9][1]=  -23.4; gi[24][9][2]=   2.9; hi[24][9][2]=  11.0;
	gi[24][9][3]=    -1.5; hi[24][9][3]=    9.8; gi[24][9][4]=  -1.1; hi[24][9][4]=  -5.1;
	gi[24][9][5]=   -13.2; hi[24][9][5]=   -6.3; gi[24][9][6]=   1.1; hi[24][9][6]=   7.8;
	gi[24][9][7]=     8.8; hi[24][9][7]=    0.4; gi[24][9][8]=  -9.3; hi[24][9][8]=  -1.4;
	gi[24][9][9]=   -11.9; hi[24][9][9]=    9.6;
	gi[24][10][0]=   -1.9;
	gi[24][10][1]=   -6.2; hi[24][10][1]=   3.4; gi[24][10][2]= -0.1; hi[24][10][2]= -0.2;
	gi[24][10][3]=    1.7; hi[24][10][3]=   3.6; gi[24][10][4]= -0.9; hi[24][10][4]=  4.8;
	gi[24][10][5]=    0.7; hi[24][10][5]=  -8.6; gi[24][10][6]= -0.9; hi[24][10][6]= -0.1;
	gi[24][10][7]=    1.9; hi[24][10][7]=  -4.3; gi[24][10][8]=  1.4; hi[24][10][8]= -3.4;
	gi[24][10][9]=   -2.4; hi[24][10][9]=  -0.1; gi[24][10][10]=-3.8; hi[24][10][10]=-8.8;

/* Secular Variation from IGRF2020 (nT/yr) */

	gi[25][1][0]=  5.7;
	gi[25][1][1]=  7.4; hi[25][1][1]=-25.9;
	gi[25][2][0]=-11.0;
	gi[25][2][1]= -7.0; hi[25][2][1]=-30.2; gi[25][2][2]= -2.1; hi[25][2][2]=-22.4;
	gi[25][3][0]=  2.2;
	gi[25][3][1]= -5.9; hi[25][3][1]=  6.0; gi[25][3][2]=  3.1; hi[25][3][2]= -1.1;
	gi[25][3][3]=-12.0; hi[25][3][3]=  0.5;
	gi[25][4][0]= -1.2;
	gi[25][4][1]= -1.6; hi[25][4][1]= -0.1; gi[25][4][2]= -5.9; hi[25][4][2]=  6.5;
	gi[25][4][3]=  5.2; hi[25][4][3]=  3.6; gi[25][4][4]= -5.1; hi[25][4][4]= -5.0;
	gi[25][5][0]= -0.3;
	gi[25][5][1]=  0.5; hi[25][5][1]=  0.0; gi[25][5][2]= -0.6; hi[25][5][2]=  2.5;
	gi[25][5][3]=  0.2; hi[25][5][3]= -0.6; gi[25][5][4]=  1.3; hi[25][5][4]=  3.0;
	gi[25][5][5]=  0.9; hi[25][5][5]=  0.3;
	gi[25][6][0]= -0.5;
	gi[25][6][1]= -0.3; hi[25][6][1]=  0.0; gi[25][6][2]=  0.4; hi[25][6][2]= -1.6;
	gi[25][6][3]=  1.3; hi[25][6][3]= -1.3; gi[25][6][4]= -1.4; hi[25][6][4]=  0.8;
	gi[25][6][5]=  0.0; hi[25][6][5]=  0.0; gi[25][6][6]=  0.9; hi[25][6][6]=  1.0;
	gi[25][7][0]= -0.1;
	gi[25][7][1]= -0.2; hi[25][7][1]=  0.6; gi[25][7][2]=  0.0; hi[25][7][2]=  0.6;
	gi[25][7][3]=  0.7; hi[25][7][3]= -0.8; gi[25][7][4]=  0.1; hi[25][7][4]= -0.2;
	gi[25][7][5]= -0.5; hi[25][7][5]= -1.1; gi[25][7][6]= -0.8; hi[25][7][6]=  0.1;
	gi[25][7][7]=  0.8; hi[25][7][7]=  0.3;
	gi[25][8][0]=  0.0;
	gi[25][8][1]=  0.1; hi[25][8][1]= -0.2; gi[25][8][2]= -0.1; hi[25][8][2]=  0.6;
	gi[25][8][3]=  0.4; hi[25][8][3]= -0.2; gi[25][8][4]= -0.1; hi[25][8][4]=  0.5;
	gi[25][8][5]=  0.4; hi[25][8][5]= -0.3; gi[25][8][6]=  0.3; hi[25][8][6]= -0.4;
	gi[25][8][7]= -0.1; hi[25][8][7]=  0.5; gi[25][8][8]=  0.4; hi[25][8][8]=  0.0;
	gi[25][9][0]=  0.0;
	gi[25][9][1]=  0.0; hi[25][9][1]=  0.0; gi[25][9][2]=  0.0; hi[25][9][2]=  0.0;
	gi[25][9][3]=  0.0; hi[25][9][3]=  0.0; gi[25][9][4]=  0.0; hi[25][9][4]=  0.0;
	gi[25][9][5]=  0.0; hi[25][9][5]=  0.0; gi[25][9][6]=  0.0; hi[25][9][6]=  0.0;
	gi[25][9][7]=  0.0; hi[25][9][7]=  0.0; gi[25][9][8]=  0.0; hi[25][9][8]=  0.0;
	gi[25][9][9]=  0.0; hi[25][9][9]=  0.0;
	gi[25][10][0]= 0.0;
	gi[25][10][1]= 0.0; hi[25][10][1]= 0.0; gi[25][10][2]= 0.0; hi[25][10][2]= 0.0;
	gi[25][10][3]= 0.0; hi[25][10][3]= 0.0; gi[25][10][4]= 0.0; hi[25][10][4]= 0.0;
	gi[25][10][5]= 0.0; hi[25][10][5]= 0.0; gi[25][10][6]= 0.0; hi[25][10][6]= 0.0;
	gi[25][10][7]= 0.0; hi[25][10][7]= 0.0; gi[25][10][8]= 0.0; hi[25][10][8]= 0.0;
	gi[25][10][9]= 0.0; hi[25][10][9]= 0.0; gi[25][10][10]=0.0; hi[25][10][10]=0.0;
}
#undef NEPOCH
