/* gaussfld.c -- main filed from Gauss coefficients n=m=10   040220
	V.3 -- Major update from V.2. The simplest sum up to n=m=10, but
		allows both geodetic & geocentric system with height or radius.
		Non-dipole options were abandoned.
	V.2 -- field elements from Gauss coeffficients   0401,0298,1295,0686
		With g[][] (h[][]) defined in the main as double **G, and memory
		allocated as G = mallocmd(n+1,n+1), values should be given by
		call of gausscoeff(..) at the very first of the main program.
	type = 0:
		geodetic system WGS84
		hr -- height from the spheroid in km (-10 ~ 500 km)
	type = 1:
		geocentric system (a=6371.2 km)
		hr -- radius from the center (3485 ~ 10000 km)
*/

#include <math.h>
#include "std.h"

#define AE 6371.2
#define A2 40680631.59
#define B2 40408299.98
#define GEODETIC 0
#define GEOCENTRIC 1

static double cd, sd;

void gaussfld(type, lat, lon, hr, n, x, y, z, g, h)
int type, n;
double lat, lon, hr, *x, *y, *z, **g, **h;
{
	double th, ph, thc, r, xc, zc;

	th = (90. - lat)/RAD;   ph = lon/RAD;
	if (type == GEODETIC){
		gdtogc(th, hr, &thc, &r);
		sumall(thc, ph, r, n, &xc, y, &zc, g, h);
		xzctoxzd(xc, zc, x, z);
	}
	else if (type == GEOCENTRIC)
		sumall(th, ph, hr, n, x, y, z, g, h);
	else
		error("Wrong type in gaussfld!");
}

/* sumall */

void sumall(th, ph, r, n, x, y, z, g, h)
int n;
double th, ph, r, *x, *y, *z, **g, **h;
{
	int i, j;
	double c, cj, sj, f, ar;
	c = cos(th);
	*x = *y = *z = 0.;
	f = (ar=AE/r)*ar;
	for (i=1; i<=n; i++){
		f *= ar;
		*x += f*g[i][0]*dlgndr(i, 0, c);
		*z -= f*g[i][0]*lgndr(i, 0, c)*(i+1.);
		for (j=1; j<=i; j++){
			cj = cos(j*ph);   sj = sin(j*ph);
			*x += f*(g[i][j]*cj + h[i][j]*sj)*dlgndr(i, j, c);
			*y += f*(g[i][j]*sj - h[i][j]*cj)*mpsin(i, j, c);
			*z -= f*(g[i][j]*cj + h[i][j]*sj)*lgndr(i, j, c)*(i+1.);
		}
	}
}

/* gdtogc -- geodetic [theta,height] to geocentric [thetac,radius] */ 

void gdtogc(th, h, thc, r)
double th, h, *thc, *r;
{
	double s, c, s2, c2, rho, dum;

	s = sin(th);   c = cos(th);
	s2 = s*s;   c2 = c*c;
	rho = sqrt(dum = A2*s2 + B2*c2);
	*r = sqrt((A2*A2*s2 + B2*B2*c2)/dum + h*(h + 2.*rho));
	cd = (h + rho)/(*r);   sd = (A2 - B2)*s*c/(*r)/rho;
	*thc = acos(c*cd - s*sd);
}

/* xzctoxzd -- geocentric [Hx,Hz] to geodetic [Hx,Hz] */

void xzctoxzd(xc, zc, x, z)
double xc, zc, *x, *z;
{
	*x = xc*cd + zc*sd;
	*z = zc*cd - xc*sd;
}
#undef AE
#undef A2
#undef B2
#undef GEODETIC
#undef GEOCENTRIC
