/* gaussfld4.c -- main field from Gauss coefficients n=m=10   111724
	V.4 -- three of the non-dipole options revived.
		nd: 0 -- include all terms for assigned n
		   -1 -- exclude axial dipole (omit g10)
		   -2 -- exclude whole dipole (omit g10, g11, and h11) 
	V.3 -- Major update from V.2. The simplest sum up to n=m=10, but   040220
		allows both geodetic (type=0) & geocentric (type=1) system
		with height or radius. Non-dipole options were abandoned.
	V.2 -- field elements from Gauss coeffficients   0401,0298,1295,0686
		With g[][] (h[][]) defined in the main as double **G, and memory
		allocated as G = mallocmd(n+1,n+1), values should be given by
		call of gausscoeff(..) at the very first of the main program.
	type = 0:
		geodetic system WGS84
		hr -- height from the spheroid in km (-10 ~ 500 km)
	type = 1:
		geocentric system (a=6371.2 km)
		hr -- radius from the center (3485 ~ 10000 km)
*/

#include <math.h>
#include "std.h"

#define AE 6371.2
#define GEODETIC 0
#define GEOCENTRIC 1
#define ALLTERM 0
#define EXAXDP -1
#define EXDP -2

static int i, j;
static double c, cj, sj, f, ar;

void gaussfld4(type, lat, lon, hr, n, nd, x, y, z, g, h)
int type, n, nd;
double lat, lon, hr, *x, *y, *z, **g, **h;
{
	double th, ph, thc, r, xc, zc;

	if (n < 1 || n > GNMAX) error("gaussfld4: incorrect n!");
	th = (90. - lat)/RAD;   ph = lon/RAD;
	if (type == GEODETIC){
		gdtogc(th, hr, &thc, &r);
		switch(nd){
		case ALLTERM:
			sumall4(thc, ph, r, 1, n, &xc, y, &zc, g, h);
			break;
		case EXAXDP:
			sumxadp4(thc, ph, r, 1, n, &xc, y, &zc, g, h);
			break;
		case EXDP:
			sumall4(thc, ph, r, 2, n, &xc, y, &zc, g, h);
			break;
		default:
			error("gaussfld4: error in non-dipole option!");
			break;
		}
		xzctoxzd(xc, zc, x, z);
	}
	else if (type == GEOCENTRIC){
		switch(nd){
		case ALLTERM:
			sumall4(th, ph, hr, 1, n, &xc, y, &zc, g, h);
			break;
		case EXAXDP:
			sumxadp4(th, ph, hr, 1, n, &xc, y, &zc, g, h);
			break;
		case EXDP:
			sumall4(th, ph, hr, 2, n, &xc, y, &zc, g, h);
			break;
		default:
			error("gaussfld4: error in non-dipole option!");
			break;
		}
		*x = xc;  *z = zc;
	}
	else
		error("Wrong type in gaussfld4!");
}

/* sumall4 */

void sumall4(th, ph, r, n1, n2, x, y, z, g, h)
int n1, n2;
double th, ph, r, *x, *y, *z, **g, **h;
{
	c = cos(th);
	*x = *y = *z = 0.;
	f = (ar=AE/r)*ar;
	for (i=n1; i<=n2; i++){
		f *= ar;
		*x += f*g[i][0]*dlgndr(i, 0, c);
		*z -= f*g[i][0]*lgndr(i, 0, c)*(i+1.);
		for (j=1; j<=i; j++){
			cj = cos(j*ph);   sj = sin(j*ph);
			*x += f*(g[i][j]*cj + h[i][j]*sj)*dlgndr(i, j, c);
			*y += f*(g[i][j]*sj - h[i][j]*cj)*mpsin(i, j, c);
			*z -= f*(g[i][j]*cj + h[i][j]*sj)*lgndr(i, j, c)*(i+1.);
		}
	}
}

/* sumxadp4 -- exclude axial dipole term (omit g10) */

void sumxadp4(th, ph, r, n1, n2, x, y, z, g, h)
int n1, n2;
double th, ph, r, *x, *y, *z, **g, **h;
{
	c = cos(th);
	*x = *y = *z = 0.;
	f = (ar=AE/r)*ar;
	for (i=n1; i<=n2; i++){
		f *= ar;
		if (i > 1){
			*x += f*g[i][0]*dlgndr(i, 0, c);
			*z -= f*g[i][0]*lgndr(i, 0, c)*(i+1.);
		}
		for (j=1; j<=i; j++){
			cj = cos(j*ph);   sj = sin(j*ph);
			*x += f*(g[i][j]*cj + h[i][j]*sj)*dlgndr(i, j, c);
			*y += f*(g[i][j]*sj - h[i][j]*cj)*mpsin(i, j, c);
			*z -= f*(g[i][j]*cj + h[i][j]*sj)*lgndr(i, j, c)*(i+1.);
		}
	}
}
#undef AE
#undef GEODETIC
#undef GEOCENTRIC
#undef ALLTERM
#undef EXAXDP
#undef EXDP
