#include <math.h>
#include "std.h"

/* #pragma options(!assign_registers) -- Does not work at SUN */	

/* linregy -- least square fitting to y = a + bx by minimum sum of the squares of
		the perpendicular distance (eq. (1) & (2) by York, 1966)   8/28/92
	Note on 8/24/00 at Misasa:
		This is actually a trasitional formula by Kermack & Haldane 1950.
		As sa gives negative content of sqrt(), York's last formula on
		p.1085 was used with Wi = 1/(b*b+1) = const, ie.,
			sa = sb*sqrt(sxx/n)
*/

void linregy(n, x, y, a, b, sa, sb, r)
int n;
double *x, *y, *a, *b, *sa, *sb, *r;
{
	int i;
	double sx=0.,sy=0.,sxx=0.,syy=0.,sxy=0.,vxx,vyy,vxy,sgx,sgy,d1,d2;
	
	if (n < 2) error("n<2 in linregy");
	if (n == 2){
		*a = (x[1]*y[0] - x[0]*y[1]) / (x[1] - x[0]);
		*b = (y[1] - y[0]) / (x[1] - x[0]);
		*sa = 0.;   *sb = 0.;
		*r = ( (*b) > 0. ) ? 1. : -1.;
		return;
	}
	for (i=0; i<n; i++){
		sx += x[i];   sy += y[i];
		sxx += x[i]*x[i];   syy += y[i]*y[i];
		sxy += x[i]*y[i];
	}
	vxx = n*sxx - sx*sx;   vyy = n*syy - sy*sy;   vxy = n*sxy - sx*sy;
	d1 = vyy - vxx;
	*b = ( d1 + sqrt( d1*d1 + 4.*vxy*vxy ) ) / vxy / 2.;
	*a = (sy - (*b)*sx) / n;
	*r = vxy / sqrt( vxx*vyy );
	*sb = (*b) * sqrt( (1. - (*r)*(*r))/n ) / (*r);
	sgx = sqrt( vxx/n/(n-1.) );   sgy = sqrt( vyy/n/(n-1.) );
	*sa = (*sb)*sqrt(sxx/n);
/*
	d1 = (sgy - sgx*(*b))*(sgy - sgx*(*b))/n;
	d2 = (1. - (*r)) * (*b) * ( 2.*sgx*sgy + sx*(*b)*(1.+(*r))/((*r)*(*r)*n) );
	*sa = sqrt( d1 + d2 );

Negative d2 gave overall negative content in sqrt() in the anzlysis of Thellier
data, which was revealed by the next line.

	printf("d1,d2,sa: %f %f %f\n", d1, d2, *sa);

*/
}

/* linregby -- least square fitting to y = bx by minimum sum of the squares of
		the perpendicular distance (York, 1966)		8/28/92
*/

void linregby(n, x, y, b, sb, r)
int n;
double *x, *y, *b, *sb, *r;
{
	int i;
	double sx=0., sy=0., sxx=0., syy=0., sxy=0., d1;

	if (n < 1) error("n<1 in linregby");
	if (n == 1){
		*b = y[0]/x[0];   *sb = 0.;   *r = 1.;
		return;
	}
	for (i=0; i<n; i++){
		sx += x[i];   sy += y[i];
		sxx += x[i]*x[i];   syy += y[i]*y[i];
		sxy += x[i]*y[i];
	}
	d1 = syy - sxx;
	*b = ( d1 + sqrt( d1*d1 + 4.*sxy*sxy) ) / sxy /2.;
	*r = (n*sxy - sx*sy) / sqrt( (n*sxx - sx*sx)*(n*syy - sy*sy) );
	*sb = (*b) * sqrt( (1.-(*r)*(*r))/n ) / (*r);
}

/* linregc -- linear regression for paleointensity by Coe et al. (1978) 
		r & sa are followed from linregy()			040502
	Ver.2: length of segment for RAT was added			061705
	Ver.2.1: EROR WAS FIXED FOR LENGTH OF SEGMENT!                  062806
	Ver.2.2: sse, square sum of right angle distance to the fitted line,
	was introduced (sse2 is to avoid overlap of the 2nd segment)    032214
	minimum distance li from (xi,yi) to y=a+b*x is given by
		li = abs( yi - (a + b*xi) )/sqrt( 1 + b^2 )
*/

void linregc(n, x, y, a, b, sa, sb, r, f, g, q, l, sse, sse2)
int n;
double *x, *y, *a, *b, *sa, *sb, *r, *f, *g, *q, *l, *sse, *sse2;
{
	int i;
	double sx=0., sy=0., sxx=0., syy=0., sxy=0., vxx, vyy, vxy, sgx, sgy,\
		serr=0., *dy, dyb, dyt = 0., dyy = 0., yt, d1, d2, dum;

	dy = mallocvd(n);
	if (n < 2) error("n<2 in linregc");
	if (n == 2){
		d1 = x[1] - x[0];   d2 = y[1] - y[0];
		*a = (x[1]*y[0] - x[0]*y[1])/d1;
		*b = d2/d1;
		*sa = 0.;   *sb = 0.;
		*r = ( (*b) > 0. ) ? 1. : -1.;
		*f = 0.;   *g = 0.;   *q = 0.;
		*l = sqrt(d1*d1 + d2*d2);
		return;
	}
	for (i=0; i<n; i++){
		sx += x[i];   sy += y[i];
		sxx += x[i]*x[i];   syy += y[i]*y[i];
		sxy += x[i]*y[i];
		if (i == 0) continue;
		dy[i-1] = y[i-1] - y[i];
		dyt += dy[i-1];   dyy += dy[i-1]*dy[i-1];
	}
	vxx = n*sxx - sx*sx;   vyy = n*syy - sy*sy;   vxy = n*sxy - sx*sy;
	*b = -sqrt(vyy/vxx);
	yt = *a = (sy - (*b)*sx)/n;
	*r = vxy/sqrt( vxx*vyy );
	*sb = RT2*sqrt( (vyy - (*b)*vxy)/vxx/(n-2.) );
	*sa = (*sb)*sqrt(sxx/n);
	*f = dyt/yt;
	dyb = dyy/dyt;
	*g = 1. - dyb/dyt;
	*q = fabs(*b)*(*f)*(*g)/(*sb);
	freevd(dy);
	d1 = x[n-1] - x[0];   d2 = y[n-1] - y[0];
	*l = sqrt(d1*d1 + d2*d2);
	for (i=0; i<n; i++)
		serr += (y[i] - (*a) - (*b)*x[i])*(y[i] - (*a) - (*b)*x[i]);
	*sse = serr/(1. + (*b)*(*b));
	dum = (y[0] - (*a) - (*b)*x[0])*(y[0] - (*a) - (*b)*x[0])/(1. + (*b)*(*b));
	*sse2 = (*sse) - dum;
}
