/* stati -- inclination only statistics of the marginal Fisher distribution,   042019
	based on Arason & Levi (2010), GJI, Vol.182, 753-771.
    Variables: (#) indicates equation number of Arason & Levi 2010
	th[] -- observed theta[i]=(90-inc[i])/RAD where i=0~n-1
	costh[], sinth[] -- cos & sin of th[i]
	scosth -- sigma_i=0^n-1 cos(th[i]): denominator of (19)
	slnsinth -- sigma_i=0^n-1 log(sin(th[i])): A3 of (14)
	t0, k0 -- initials of max. likelihood estimate (mle) of t & k: (17), (18)
	t, tp -- new & previous mle_th during iteration in (19), (20)
	k, kp -- new & previous mle_k during iteration in (19), (20)
	(calculation is ceased after ITMAX iterations or k becomes k<1) 
	tm, *km -- mle t and k after iteration converged
	h, h1, it1 -- log-likelihood (14) and its converged/stopped value after it1
	h2, h3, h4 -- boundary h at tm=0, tm=pi, k=0: through (21) or (11)
	(h1, h2, etc. are written to stderr when ITMAX is reached or k<3)
    Return:
	number of iterations it1
*/

#include <math.h>
#include "std.h"

#define EPS 1.e-6
#define EPST 2.e-8
#define EPSK 1.e-6
#define ITMAX 10000
#define CONV0 "* VERY SMALL k OR BAD CONVERGENCE? *\n  h0=%12.9f (t0=%5.2f, k0=%5.2f)\n"
#define CONV1 "  h1=%12.9f (tm=%5.2f, km=%5.2f, it=%d)\n"
#define CONV2 "  h2=%12.9f (t2=  0, k2=%5.2f, it=%d)\n"
#define CONV3 "  h3=%12.9f (t3=180, k3=%5.2f, it=%d)\n"
#define CONV4 "  h4=%12.9f (t4= 90, k4=0)\n"

static double p[]={1.,3.5156229,3.0899424,1.2067492,.2659732,.0360768,.0045813};
static double q[]={.39894228,.01328592,.00225319,-.00157565,.00916281,-.02057706,.02635537,-.01647633,.00392377};
static double u[]={.5,.87890594,.51498869,.15084934,.02658733,.00301532,.00032411};
static double v[]={.39894228,-.03988024,-.00362018,.00163801,-.01031555,.02282967,-.02895312,.01787654,-.00420059};
static double y2, y4, y6, y8, y10, y12, z1, z2, z3, z4, z5, z6, z7, z8;
static double lnH(), R(), lnB(), P(), Q(), U(), V();

int stati(inc, n, incm, km, alph)
int n;
double *inc, *incm, *km, *alph;
{
	int i, it, it1, it2, it3, flagcnv = 0;
	double coth();
	double nd, *th, *costh, *sinth, scosth, slnsinth, t0, k0, t, tp, dt, k, kp, dk, \
		s, ss, dum, h, h0, h1, h2, h3, h4, tm, k2, k3;

	if (n < 2) error("Data number is less than 2!");
	th = mallocvd(n);  costh = mallocvd(n);  sinth = mallocvd(n);
	nd = n;  s = ss = scosth = slnsinth = 0.;
	for (i=0; i<n; i++){
		th[i] = (90. - inc[i])/RAD;
		costh[i] = cos(th[i]);
		sinth[i] = dum = sin(th[i]);
		s += th[i];  ss += th[i]*th[i];  scosth += costh[i];
		if (dum < EPS) dum = EPS;
		slnsinth += log(dum);
	}
	t0 = s/nd;  k0 = nd*(nd - 1.)/(nd*ss - s*s);
	h0 = lnH(n, nd, t0, k0, th, sinth, slnsinth);
/* printf("h0: %12.9f\n", h0); */

/* iteration within the space */

	t = t0;  k = k0;  dt = dk = 1.;
	it = 0;
/* printf("it,t,tp,dt,k,kp,dk,h:\n"); */
	while (dt>EPST || dk>EPSK){
		tp = t;  kp = k;
		s = 0.;
		for (i=0; i<n; i++)
			s += sinth[i]*R(kp*sin(tp)*sinth[i]);
		t = atan2(s, scosth);
		s = 0.;
		for (i=0; i<n; i++)
			s += cos(t)*costh[i] + sin(t)*sinth[i]*R(kp*sin(t)*sinth[i]);
		k = 1./(coth(kp) - s/nd);
		dt = fabs(t-tp);   dk = fabs((k-kp)/k);
		it += 1;
/*
h = lnH(n, nd, t, k, th, sinth, slnsinth);
printf("%3d %12.9f %12.9f %12.9f %12.9f %12.9f %12.9f %12.9f\n",it,RAD*t,RAD*tp,RAD*dt,k,kp,dk,h);
*/
		if (it >= ITMAX) { flagcnv = 1;  break; }
	}
	it1 = it;
	h1 = lnH(n, nd, t, k, th, sinth, slnsinth);
	tm = t;   *km = k;

/* iteration at the boundary: t=0 */

	k = k0;  dk = 1.;
	it = 0;
/* printf("it,k,kp,dk,h:\n"); */
	while (dk > EPSK){
		kp = k;
		k = 1./(coth(kp) - scosth/nd);
		dk = fabs((k-kp)/k);
/*
h = lnH(n, nd, 0., k, th, sinth, slnsinth);
printf("%3d %12.9f %12.9f %12.9f %12.9f\n",it,k,kp,dk,h);
*/
		it += 1;
		if (it>=ITMAX || k<1.0) break;
	}
	it2 = it;
	h2 = lnH(n, nd, 0., k, th, sinth, slnsinth);
	k2 = k;

/* iteration at the boundary: t=pi */

	k = k0;  dk = 1.;
	it = 0;
/* printf("it,k,kp,dk,h:\n"); */
	while (dk > EPSK){
		kp = k;
		k = 1./(coth(kp) + scosth/nd);
		dk = fabs((k-kp)/k);
/*
h = lnH(n, nd, PAI-EPS, k, th, sinth, slnsinth);
printf("%3d %12.9f %12.9f %12.9f %12.9f\n",it,k,kp,dk,h);
*/
		it += 1;
		if (it>=ITMAX || k<1.0) break;
	}
	it3 = it;
	h3 = lnH(n, nd, PAI-EPS, k, th, sinth, slnsinth);
	k3 = k;

/* h(k=0,t=pi/2) of (11) */

	h4 = -nd*LN2 + slnsinth;
/* printf("h4: %12.9f\n", h4); */

/* alpha95 and check of convergence and very small k */

	*incm = 90. - RAD*tm;
	dum = 1. - (nd - 1.)*(pow(20.,1./(nd-1.)) - 1.)/(nd*((*km) - 1.) + 1.);
	if (dum>1. || dum<-1.) *alph = 180.;
	else *alph = RAD*acos(dum);
	if ((*km)<=3. || flagcnv>0 || h2>=h1 || h3>=h1 || h4>=h1){
		fprintf(stderr, CONV0, h0, t0*RAD, k0);
		fprintf(stderr, CONV1, h1, (tm)*RAD, (*km), it1);
		fprintf(stderr, CONV2, h2, k2, it2);
		fprintf(stderr, CONV3, h3, k3, it3);
		fprintf(stderr, CONV4, h4);
	}
	freevd(th);  freevd(costh);  freevd(sinth);
	return(it1);
}

/* lnH -- A1 + A2 + A3 of the log-likelihood h of (14), (A36), (A37), (A38), (A42).
	A3 (A29, slnsinth) should be supplied from the host program, it just goes through.
*/

static double lnH(n, nd, t, k, th, sinth, slnsinth)
int n;
double nd, t, k, *th, *sinth, slnsinth;
{
	int i;
	double A1, A2, x, dum;
	double c1=-1., c2=.666666666667, c3=-.333333333333, c4=.133333333333, c5=-.177777777778;

	if (k < 0.) error("Negative k in lnH!");
	if (k < 0.01){
		dum = 1. + k*(c1 + k*(c2 + k*(c3 + k*(c4 + c5*k))));
		A1 = nd*(-LN2 - log(dum) - k);
	}
	else if (k <= 15.)
		A1 = nd*(log(k) - log(1. - exp(-2.*k)) - k);
	else
		A1 = nd*(log(k) - k);
	A2 = 0.;
	for (i=0; i<n; i++){
		x = k*sin(t)*sinth[i];
		A2 += k*cos(th[i]-t) + lnB(x);
	}
	return (A1 + A2 + slnsinth);
}

/* R -- x derivative of logarithm of modified Bessel funciton I0(x) by AL10; (A20), (A21).
		R(x) = d_log(I0(x))/d_x = I0'(x)/I0(x) = I1(x)/I0(x)
*/

static double R(x)
double x;
{
	if (x < 0.) error("Negative x in R(x)!");
	if (x < 3.75){
		y2=(x/3.75)*(x/3.75); y4=y2*y2; y6=y2*y4; y8=y4*y4; y10=y2*y8; y12=y6*y6;
		return U(x)/P();
	}
	else {
		z1=3.75/x; z2=z1*z1; z3=z1*z2; z4=z2*z2; z5=z2*z3; z6=z3*z3; z7=z3*z4; z8=z4*z4;
		return V()/Q();
	}
}

/* lnB -- logarithm of B(x) which appears in A2 given by (A42). B(x) is given by (A18) and (A19).
	log(B(x)) = log(P(x)) - x  (0 <= x < 3.75),
	log(B(x)) = log(Q(x)) - 0.5*log(x)  (3.75 <= x).
*/

static double lnB(x)
double x;
{
	if (x < 0.) error("Negative x in lnB(x)!");
	if (x < 3.75){
		y2=(x/3.75)*(x/3.75); y4=y2*y2; y6=y2*y4; y8=y4*y4; y10=y2*y8; y12=y6*y6;
		return log(P(x)) - x;
	}
	else {
		z1=3.75/x; z2=z1*z1; z3=z1*z2; z4=z2*z2; z5=z2*z3; z6=z3*z3; z7=z3*z4; z8=z4*z4;
		return log(Q(x)) - 0.5*log(x);
	}
}

/* P, Q, U, V -- (A3) ~ (A11). Befor calling these functions, you should set the values of
	y2=(x/3.75)*(x/3.75), y4=y2*y2, ... etc. in R(x) or lnB(x).
*/

static double P()
{
	return p[0] + p[1]*y2 + p[2]*y4 + p[3]*y6 + p[4]*y8 + p[5]*y10 + p[6]*y12;
}

static double Q()
{
	return q[0] + q[1]*z1 + q[2]*z2 + q[3]*z3 + q[4]*z4 + q[5]*z5 + q[6]*z6 + q[7]*z7 + q[8]*z8;
}

static double U(x)
double x;
{
	double dum;

	dum = u[0] + u[1]*y2 + u[2]*y4 + u[3]*y6 + u[4]*y8 + u[5]*y10 + u[6]*y12;
	return x*dum;
}

static double V()
{
	return v[0] + v[1]*z1 + v[2]*z2 + v[3]*z3 + v[4]*z4 + v[5]*z5 + v[6]*z6 + v[7]*z7 + v[8]*z8;
}

/* coth -- approximation of coth(x) for x>0 by Arason & Levi (2010).
	this fnction will be in general use, hence included in stdlib.
*/

double coth(x)
double x;
{
	double d, d2, d3, d5;

	if (x < EPS) error("Negative or too small x in coth of AL10!");
	if (x < 0.01){
		d2 = x*x;  d3 = x*d2;  d5 = d2*d3;
		return 1./x + x/3. - d3/45. + 2.*d5/945.;
	}
	else if (x <= 15.){
		d = exp(-2.*x);
		return (1. + d)/(1. - d);
	}
	else
		return(1.);
}
#undef EPS
#undef EPST
#undef EPSK
#undef ITMAX
#undef CONV0
#undef CONV1
#undef CONV2
#undef CONV3
#undef CONV4
