/* sundir -- returns the sun azimuth measured WESTWARD from SOUTH   021919
	The source code is created after the following publication:
		Yallop, B. D., and C. Y. Hohenkerk,
		Astronomical Algorithms for use with Micro-computers,
		NAO Technical Note No.67, HM Nautical Almanac Office,
		United Kingdom Hydrographic Office, 1989 (2007 updated).
	The algorithm of spherical trigonometry to calculate the sun's azimuth &
	altitude is after the source code by Prof. Masaru Kono in 1970's.

	lat: site latitude
	lon: site longitude
	yr,mo,dy: calendar date
		(-2000<=year<=2200 for accuracy of 0.6' in the sun azimuth)
	hr,mi,sc: site local time (0<=hr<24, 0<=mi<60, 0<=sc<60)
	sld: standard logitude difference in hour, i.e. difference in time
		(east positive, ex. +9 for Japan, -10 for Hawaii Island)
	gha: Greenwich hour angle of the sun in deg
	lha: local hour angle of the sun at the site in deg
	dec: declination of the sun (NOT the declination of the geomagnetic field)
	azim: azimuth of the sun at the site in deg (WESTWARD POSITIVE from SOUTH)
	altd: altitude of the sun at the site, returned as an argument
*/

#include <math.h>
#include "std.h"

double sundir(lat, lon, yr, mo, dy, hr, mi, sc, sld, altd)
double lat, lon, yr, mo, dy, hr, mi, sc, sld, *altd;
{
	double jd, h, gha, lha, dec, azim;

	julid(yr, mo, dy, hr, mi, sc, sld, &jd, &h);
	sunrd(jd, h, &gha, &dec);
	lha = fmod(gha+lon, 360.);
	sunzl(lat, lha, dec, &azim, altd);
	return(azim);
}

/* sunzl -- azimuth & altitude of the sun at the observation site */

void sunzl(lat, lha, dec, azim, altd)
double lat, lha, dec, *azim, *altd;
{
	double coslat, sinlat, coslha, sinlha, cosdec, sindec, tandec;

	coslat = cos(lat/RAD);   sinlat = sin(lat/RAD);
	coslha = cos(lha/RAD);   sinlha = sin(lha/RAD);
	cosdec = cos(dec/RAD);   sindec = sin(dec/RAD);   tandec = tan(dec/RAD);
	*altd = RAD*asin(sinlat*sindec + coslat*cosdec*coslha);
	*azim = RAD*atan2(sinlha, sinlat*coslha - coslat*tandec);
}

/* sunrd -- Greenwich hour angle and declination of the sun
	jd: Julian date at 0h UT (i.e. 0.5 earlier than the usual one at noon)
	h: time at Greenwich (i.e. UT) in hour (ex. 6.5083)
	ras: right ascention in deg
	dec: declination in deg
	gha: Greenwich hour angle in deg
	D: number of days with time fraction from 2000 January 12h UT (i.e. noon)
	t: time interval in Julian centries of 36525 days from 2000 January 12h UT
	dt: difference between Terrestrial Time and Universal Time (TT - UT1)
	tt: t corrected for Terrestrial Time, tt=t+dt
	elonm: mean ecliptic longitude in deg
	elon,elonr: apparent ecliptic longitude in deg & radian
	G,Gr: mean anomaly in deg & radian
	eps0,eps0r: mean obliquity of the ecliptic in deg & radian
	eps,epsr: obliquity of the ecliptic in deg & radian
	C: equation of the center
	omg,omgr: longitude of the Moon's node used to correct the center and nutation
	       (corrction for abberation is -0.0057 deg = -20.52 s)
	E: equation of time in deg
*/

void sunrd(jd, h, gha, dec)
double jd, h, *gha, *dec;
{
	double D, t, dt, tt, elonm, elon, elonr, G, Gr, eps0, eps0r, eps, epsr, C, omg, omgr, \
		ras, A, x, y, z, E, dum, dum1;

	D = jd + h/24. - 2451545.;
	t = D/36525.;
	if ((jd > 2067679.5) || (jd < 1578610.5))
		dt = 0.808*(t-2.)*(t-2.)*1.e-8;
/*		dt = 69.184/(3600.*24.*36525.); AD 2017 */
	else
		dt = (28.43 + 4.525*t + 1.404*t*t)*1.e-8;
	tt = t + dt;
	elonm = fmod(280.46645 + 36000.76975*tt + 0.0003132*tt*tt, 360.);
	G = fmod(357.529 + 35999.05029*tt, 360.);   Gr = G/RAD;
	eps0 = 23.4393 - 0.01301*tt - 0.0000001*tt*tt + 0.0000006*tt*tt*tt;
	eps0r = eps0/RAD;
	C = (1.9147 - 0.00482*tt - 0.000015*tt*tt)*sin(Gr) + 0.01999*sin(2.*Gr);
	omg = fmod(125.045 - 1934.136*tt, 360.);   omgr = omg/RAD;
	eps = eps0 + 0.0026*cos(omgr);   epsr = eps/RAD;
	elon = fmod(elonm + C - 0.0057 - 0.0048*sin(omgr), 360.);   elonr = elon/RAD;
	ras = RAD*atan2(cos(epsr)*sin(elonr), cos(elonr));
	if (ras < 0.) ras += 360.;
	*dec = RAD*asin(sin(epsr)*sin(elonr));
	dum = 100.4606+36000.76998*t+0.000387*t*t+15.*h-0.0048*sin(omgr)*cos(eps0r)-ras;
	*gha = fmod(dum, 360.);
	if ((*gha) < 0.) *gha += 360.;
	E = *gha - (15.*h - 180.);
	if (E > 10.) E -= 360.;
}

/* julid -- calculate the Julian date at 0h UT (i.e. MIDNIGHT!) (Yallop & Hahenkerk 2007)
	sld: standard logitude difference in hours (east +) at the site (ex. 9 for Japan)
	hr,mi,sc: local time at the site (ex. 15 30 30)
	jd: Julian date at 0h UT (i.e. 0.5 earlier than the usual one at noon)
	h: time at Greenwich (i.e. UT) in the unit of hour (ex. 6.5083)
*/

void julid(yr, mo, dy, hr, mi, sc, sld, jd, h)
double yr, mo, dy, hr, mi, sc, sld, *jd, *h;
{
	double y, m, J, G, dum1, dum2;

	*h = hr + mi/60. + sc/3600. - sld;
	if (mo > 2.){
		y = yr;   m = mo - 3.;
	}
	else {
		y = yr - 1.;   m = mo + 9.;
	}
	modf(365.25*(y + 4712.), &dum1);   modf(30.6*m + .5, &dum2);
	J = dum1 + dum2 + 59. + dy - .5;
	if (yr>1582. || (yr==1582. && mo>11.) || (yr==1582. && mo==10. && dy>=15.)){
		modf(49. + y/100., &dum1);   modf(3.*dum1/4., &dum2);
		G = 38. - dum2;
	}
	else
		G = 0.;
	*jd = J + G;
}
/*
printf("t,h: %12.8f %12.8f\n", lha, altd);
printf("[New ] t,dt,T,elonm,eps0,elon,eps: %12.9f %9.6e %12.9f %12.8f %12.8f %12.8f %12.8f\n",t,dt,tt,elonm,eps0,elon,eps);
printf("[New ] ras,dec,gha,E: %12.8f %12.8f %12.8f %12.8f  ", ras, *dec, *gha, E);
*/
